aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--epan/dissectors/packet-acn.c18
-rw-r--r--epan/dissectors/packet-aprs.c2
-rw-r--r--epan/dissectors/packet-arp.c4
-rw-r--r--epan/dissectors/packet-asterix.c4
-rw-r--r--epan/dissectors/packet-at.c6
-rw-r--r--epan/dissectors/packet-cdma2k.c2
-rw-r--r--epan/dissectors/packet-daap.c2
-rw-r--r--epan/dissectors/packet-dcom.c6
-rw-r--r--epan/dissectors/packet-dhcp.c2
-rw-r--r--epan/dissectors/packet-dis.c12
-rw-r--r--epan/dissectors/packet-dnp.c2
-rw-r--r--epan/dissectors/packet-dof.c10
-rw-r--r--epan/dissectors/packet-dsr.c4
-rw-r--r--epan/dissectors/packet-ethertype.c2
-rw-r--r--epan/dissectors/packet-etsi_card_app_toolkit.c4
-rw-r--r--epan/dissectors/packet-fcsb3.c2
-rw-r--r--epan/dissectors/packet-fmp_notify.c2
-rw-r--r--epan/dissectors/packet-forces.c2
-rw-r--r--epan/dissectors/packet-gbcs.c32
-rw-r--r--epan/dissectors/packet-gelf.c2
-rw-r--r--epan/dissectors/packet-geonw.c4
-rw-r--r--epan/dissectors/packet-gmr1_rr.c8
-rw-r--r--epan/dissectors/packet-gre.c86
-rw-r--r--epan/dissectors/packet-grpc.c6
-rw-r--r--epan/dissectors/packet-gsm_abis_om2000.c10
-rw-r--r--epan/dissectors/packet-gsm_abis_oml.c8
-rw-r--r--epan/dissectors/packet-gsm_abis_pgsl.c2
-rw-r--r--epan/dissectors/packet-gsm_bssmap_le.c2
-rw-r--r--epan/dissectors/packet-gsm_cbch.c2
-rw-r--r--epan/dissectors/packet-gsm_rlcmac.c18
-rw-r--r--epan/dissectors/packet-gsm_sim.c2
-rw-r--r--epan/dissectors/packet-gtp.c6
-rw-r--r--epan/dissectors/packet-gtpv2.c2
-rw-r--r--epan/dissectors/packet-homeplug-av.c26
-rw-r--r--epan/dissectors/packet-homeplug.c2
-rw-r--r--epan/dissectors/packet-pdcp-lte.c2
-rw-r--r--epan/dissectors/packet-quic.c2
-rw-r--r--epan/dissectors/packet-z3950.c6
-rw-r--r--epan/dissectors/packet-zbee-zcl-general.c6
-rw-r--r--epan/dissectors/packet-zbee-zcl-hvac.c8
-rw-r--r--epan/dissectors/packet-zbee-zcl-lighting.c6
-rw-r--r--epan/dissectors/packet-zbee-zdp.c6
-rw-r--r--epan/dissectors/packet-zbee-zdp.h4
-rw-r--r--epan/dissectors/packet-zebra.c46
-rw-r--r--epan/dissectors/packet-zvt.c2
45 files changed, 196 insertions, 196 deletions
diff --git a/epan/dissectors/packet-aprs.c b/epan/dissectors/packet-aprs.c
index 02571af0cc..5b7bbf8225 100644
--- a/epan/dissectors/packet-aprs.c
+++ b/epan/dissectors/packet-aprs.c
@@ -1709,7 +1709,7 @@ proto_register_aprs( void )
NULL, HFILL }
},
{ &hf_aprs_mic_e_long_h,
- { "Longitude hundreths of minutes", "aprs.mic_e.long_h",
+ { "Longitude hundredths of minutes", "aprs.mic_e.long_h",
FT_UINT8, BASE_HEX, NULL, 0x0,
NULL, HFILL }
},
diff --git a/epan/dissectors/packet-arp.c b/epan/dissectors/packet-arp.c
index e478ee0a73..c1465cb398 100644
--- a/epan/dissectors/packet-arp.c
+++ b/epan/dissectors/packet-arp.c
@@ -290,7 +290,7 @@ static const value_string op_vals[] = {
{ARPOP_MARS_SJOIN, "mars sjoin" },
{ARPOP_MARS_SLEAVE, "mars sleave" },
{ARPOP_MARS_GROUPLIST_REQUEST, "mars grouplist request" },
- {ARPOP_MARS_GROUPLIST_REPLY, "mars gruoplist reply" },
+ {ARPOP_MARS_GROUPLIST_REPLY, "mars grouplist reply" },
{ARPOP_MARS_REDIRECT_MAP, "mars redirect map" },
{ARPOP_MAPOS_UNARP, "mapos unarp" },
{ARPOP_EXP1, "experimental 1" },
@@ -323,7 +323,7 @@ static const value_string atmop_vals[] = {
{ARPOP_MARS_SJOIN, "mars sjoin" },
{ARPOP_MARS_SLEAVE, "mars sleave" },
{ARPOP_MARS_GROUPLIST_REQUEST, "mars grouplist request" },
- {ARPOP_MARS_GROUPLIST_REPLY, "mars gruoplist reply" },
+ {ARPOP_MARS_GROUPLIST_REPLY, "mars grouplist reply" },
{ARPOP_MARS_REDIRECT_MAP, "mars redirect map" },
{ARPOP_MAPOS_UNARP, "mapos unarp" },
{ARPOP_EXP1, "experimental 1" },
diff --git a/epan/dissectors/packet-asterix.c b/epan/dissectors/packet-asterix.c
index 34c8a8147b..a240954c02 100644
--- a/epan/dissectors/packet-asterix.c
+++ b/epan/dissectors/packet-asterix.c
@@ -6597,7 +6597,7 @@ static const value_string valstr_021_210_LTT[] = {
};
static const value_string valstr_021_210_DTI[] = {
{ 0, "Unknown" },
- { 1, "Aircraft equiped with CDTI" },
+ { 1, "Aircraft equipped with CDTI" },
{ 0, NULL }
};
static const value_string valstr_021_210_MDS[] = {
@@ -12622,7 +12622,7 @@ void proto_register_asterix (void)
{ &hf_011_290_02_SSR, { "SSR [s]", "asterix.011_290_02_SSR", FT_DOUBLE, BASE_NONE, NULL, 0x0, NULL, HFILL } },
{ &hf_011_290_03, { "#3: Mode 3/A Age", "asterix.011_290_03", FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL } },
{ &hf_011_290_03_MDA, { "MDA [s]", "asterix.011_290_03_MDA", FT_DOUBLE, BASE_NONE, NULL, 0x0, NULL, HFILL } },
- { &hf_011_290_04, { "#4: Meausered Flight Level Age", "asterix.011_290_04", FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL } },
+ { &hf_011_290_04, { "#4: Measured Flight Level Age", "asterix.011_290_04", FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL } },
{ &hf_011_290_04_MFL, { "MFL [s]", "asterix.011_290_04_MFL", FT_DOUBLE, BASE_NONE, NULL, 0x0, NULL, HFILL } },
{ &hf_011_290_05, { "#5: Mode S Age", "asterix.011_290_05", FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL } },
{ &hf_011_290_05_MDS, { "MDS [s]", "asterix.011_290_05_MDS", FT_DOUBLE, BASE_NONE, NULL, 0x0, NULL, HFILL } },
diff --git a/epan/dissectors/packet-at.c b/epan/dissectors/packet-at.c
index 6975707745..124d1a6a36 100644
--- a/epan/dissectors/packet-at.c
+++ b/epan/dissectors/packet-at.c
@@ -1708,8 +1708,8 @@ static const at_cmd_t at_cmds[] = {
{ "+CHLD", "Call Hold and Multiparty Handling", check_chld, dissect_chld_parameter },
{ "+CHUP", "Call Hang-up", check_chup, dissect_no_parameter },
{ "+CIEV", "Indicator Events Reporting", check_ciev, dissect_ciev_parameter },
- { "+CIMI", "Request International Mobile Subsciber Identity (IMSI)", check_cimi, dissect_cimi_parameter },
- { "^CIMI", "Request International Mobile Subsciber Identity (IMSI)", check_cimi, dissect_cimi_parameter },
+ { "+CIMI", "Request International Mobile Subscriber Identity (IMSI)", check_cimi, dissect_cimi_parameter },
+ { "^CIMI", "Request International Mobile Subscriber Identity (IMSI)", check_cimi, dissect_cimi_parameter },
{ "+CIND", "Phone Indicators", check_cind, dissect_cind_parameter },
{ "+CLAC", "List All Available AT Commands", check_clac, dissect_no_parameter },
{ "+CLCC", "Current Calls", check_clcc, dissect_clcc_parameter },
@@ -2550,7 +2550,7 @@ proto_register_at_command(void)
NULL, HFILL}
},
{ &hf_ccwa_show_result_code,
- { "Show Result Code Presentation Status", "at.ccwa.presentaion_status",
+ { "Show Result Code Presentation Status", "at.ccwa.presentation_status",
FT_UINT32, BASE_DEC, VALS(ccwa_show_result_code_vals), 0,
NULL, HFILL}
},
diff --git a/epan/dissectors/packet-cdma2k.c b/epan/dissectors/packet-cdma2k.c
index 2b1dc04825..8420cc0b8c 100644
--- a/epan/dissectors/packet-cdma2k.c
+++ b/epan/dissectors/packet-cdma2k.c
@@ -725,7 +725,7 @@ static const value_string Page_Req_Service_Option_Types[] = {
{39, "GSM Circuit Data" },
{40, "GSM Packet Data" },
{41, "GSM Short Message Service" },
- //42 - 53 None Reserved for MC-MAP standard service options" },
+ //42 - 53 None Reserved for MC-MAP standard service options
{54, "Markov Service Option (MSO)" },
{55, "Loopback Service Option (LSO)" },
{56, "Selectable Mode Vocoder" },
diff --git a/epan/dissectors/packet-daap.c b/epan/dissectors/packet-daap.c
index 255be50859..038407881f 100644
--- a/epan/dissectors/packet-daap.c
+++ b/epan/dissectors/packet-daap.c
@@ -724,7 +724,7 @@ proto_register_daap(void)
FT_UINT64, BASE_HEX, NULL, 0, NULL, HFILL }
},
{ &hf_daap_status,
- { "Staus", "daap.status",
+ { "Status", "daap.status",
FT_UINT32, BASE_HEX, NULL, 0, NULL, HFILL }
},
{ &hf_daap_rev,
diff --git a/epan/dissectors/packet-dcom.c b/epan/dissectors/packet-dcom.c
index 2d95c2d862..85fec9638d 100644
--- a/epan/dissectors/packet-dcom.c
+++ b/epan/dissectors/packet-dcom.c
@@ -194,7 +194,7 @@ static int hf_dcom_vt_bstr = -1;
static int hf_dcom_vt_byref = -1;
static int hf_dcom_vt_dispatch = -1;
-static expert_field ei_dcom_dissetion_incomplete = EI_INIT;
+static expert_field ei_dcom_dissection_incomplete = EI_INIT;
static expert_field ei_dcom_no_spec = EI_INIT;
static expert_field ei_dcom_hresult_expert = EI_INIT;
static expert_field ei_dcom_dualstringarray_mult_ip = EI_INIT;
@@ -935,7 +935,7 @@ dissect_dcom_tobedone_data(tvbuff_t *tvb, int offset,
item = proto_tree_add_item(tree, hf_dcom_tobedone, tvb, offset, length, ENC_NA);
proto_item_set_generated(item);
- expert_add_info(pinfo, item, &ei_dcom_dissetion_incomplete);
+ expert_add_info(pinfo, item, &ei_dcom_dissection_incomplete);
offset += length;
@@ -2460,7 +2460,7 @@ proto_register_dcom (void)
};
static ei_register_info ei[] = {
- { &ei_dcom_dissetion_incomplete, { "dcom.dissetion_incomplete", PI_UNDECODED, PI_WARN, "Dissection incomplete", EXPFILL }},
+ { &ei_dcom_dissection_incomplete, { "dcom.dissection_incomplete", PI_UNDECODED, PI_WARN, "Dissection incomplete", EXPFILL }},
{ &ei_dcom_no_spec, { "dcom.no_spec", PI_UNDECODED, PI_NOTE, "No specification available, dissection not possible", EXPFILL }},
{ &ei_dcom_hresult_expert, { "dcom.hresult.expert", PI_RESPONSE_CODE, PI_NOTE, "Hresult", EXPFILL }},
{ &ei_dcom_dualstringarray_mult_ip, { "dcom.dualstringarray.mult_ip", PI_UNDECODED, PI_NOTE, "DUALSTRINGARRAY Multiple IP", EXPFILL }},
diff --git a/epan/dissectors/packet-dhcp.c b/epan/dissectors/packet-dhcp.c
index 5ec7f0c052..28317c3898 100644
--- a/epan/dissectors/packet-dhcp.c
+++ b/epan/dissectors/packet-dhcp.c
@@ -9246,7 +9246,7 @@ proto_register_dhcp(void)
NULL, HFILL }},
{ &hf_dhcp_option_isns_server_security_bitmap_aggressive_mode,
- { "Aggresive Mode", "dhcp.option.isns.server_security_bitmap.aggressive_mode",
+ { "Aggressive Mode", "dhcp.option.isns.server_security_bitmap.aggressive_mode",
FT_BOOLEAN, 16, TFS(&tfs_enabled_disabled), F_ISNS_SRV_SEC_BITMAP_AGGRESSIVE,
NULL, HFILL }},
diff --git a/epan/dissectors/packet-dis.c b/epan/dissectors/packet-dis.c
index 7a204652b4..98ab7fa97d 100644
--- a/epan/dissectors/packet-dis.c
+++ b/epan/dissectors/packet-dis.c
@@ -951,7 +951,7 @@ typedef enum
DIS_EMISSION_FUNCTION_IMAGING = 11,
DIS_EMISSION_FUNCTION_MOTION_DETECTION = 12,
DIS_EMISSION_FUNCTION_NAVIGATION = 13,
- DIS_EMISSION_FUNCTION_WEATHER_METEROLOGICAL = 14,
+ DIS_EMISSION_FUNCTION_WEATHER_METEOROLOGICAL = 14,
DIS_EMISSION_FUNCTION_INSTRUMENTATION = 15,
DIS_EMISSION_FUNCTION_IDENTIFICATION_CLASSIFICATION_INCLUDING_IFF = 16,
DIS_EMISSION_FUNCTION_AAA_FIRE_CONTROL = 17,
@@ -1042,7 +1042,7 @@ static const value_string DIS_PDU_EmissionFunction_Strings[] =
{DIS_EMISSION_FUNCTION_IMAGING, "Imaging" },
{DIS_EMISSION_FUNCTION_MOTION_DETECTION, "Motion Detection" },
{DIS_EMISSION_FUNCTION_NAVIGATION, "Navigation" },
- {DIS_EMISSION_FUNCTION_WEATHER_METEROLOGICAL, "Weather / Meterological"},
+ {DIS_EMISSION_FUNCTION_WEATHER_METEOROLOGICAL, "Weather / Meteorological"},
{DIS_EMISSION_FUNCTION_INSTRUMENTATION, "Instrumentation" },
{DIS_EMISSION_FUNCTION_IDENTIFICATION_CLASSIFICATION_INCLUDING_IFF,
"Identification/Classification (including IFF)" },
@@ -4525,7 +4525,7 @@ static int hf_dis_em_beam_parameter_index = -1;
static int hf_dis_em_fund_frequency = -1;
static int hf_dis_em_fund_frequency_range = -1;
static int hf_dis_em_fund_effective_radiated_power = -1;
-static int hf_dis_em_fund_pulse_repition_freq = -1;
+static int hf_dis_em_fund_pulse_repetition_freq = -1;
static int hf_dis_em_fund_pulse_width = -1;
static int hf_dis_em_fund_beam_azimuth_center = -1;
static int hf_dis_em_fund_beam_azimuth_sweep = -1;
@@ -6326,7 +6326,7 @@ static int dissect_DIS_PARSER_ELECTROMAGNETIC_EMISSION_PDU(tvbuff_t *tvb, packet
offset += 4;
proto_tree_add_item(fundamental_tree, hf_dis_em_fund_effective_radiated_power, tvb, offset, 4, ENC_BIG_ENDIAN);
offset += 4;
- proto_tree_add_item(fundamental_tree, hf_dis_em_fund_pulse_repition_freq, tvb, offset, 4, ENC_BIG_ENDIAN);
+ proto_tree_add_item(fundamental_tree, hf_dis_em_fund_pulse_repetition_freq, tvb, offset, 4, ENC_BIG_ENDIAN);
offset += 4;
proto_tree_add_item(fundamental_tree, hf_dis_em_fund_pulse_width, tvb, offset, 4, ENC_BIG_ENDIAN);
offset += 4;
@@ -9888,8 +9888,8 @@ void proto_register_dis(void)
FT_FLOAT, BASE_NONE, NULL, 0x0,
NULL, HFILL}
},
- { &hf_dis_em_fund_pulse_repition_freq,
- { "Pulse Repetition Frequency", "dis.em.fund.pulse_repition_freq",
+ { &hf_dis_em_fund_pulse_repetition_freq,
+ { "Pulse Repetition Frequency", "dis.em.fund.pulse_repetition_freq",
FT_FLOAT, BASE_NONE, NULL, 0x0,
NULL, HFILL}
},
diff --git a/epan/dissectors/packet-dnp.c b/epan/dissectors/packet-dnp.c
index 35bd449093..3f78aaee03 100644
--- a/epan/dissectors/packet-dnp.c
+++ b/epan/dissectors/packet-dnp.c
@@ -958,7 +958,7 @@ static const value_string dnp3_al_obj_vals[] = {
{ AL_OBJ_DA_OS_DS, "Device Attributes - Number of outstation-defined data sets (Obj:00, Var:215)" },
{ AL_OBJ_DA_BO_REQ, "Device Attributes - Max number of binary outputs per request (Obj:00, Var:216)" },
{ AL_OBJ_DA_LOC_TA, "Device Attributes - Local timing accuracy (Obj:00, Var:217)" },
- { AL_OBJ_DA_DUR_TA, "Device Attributes - Duration of timing accuraccy (Obj:00, Var:218)" },
+ { AL_OBJ_DA_DUR_TA, "Device Attributes - Duration of timing accuracy (Obj:00, Var:218)" },
{ AL_OBJ_DA_AO_EVT, "Device Attributes - Support for analog output events (Obj:00, Var:219)" },
{ AL_OBJ_DA_MAX_AO, "Device Attributes - Max analog output index (Obj:00, Var:220)" },
{ AL_OBJ_DA_NUM_AO, "Device Attributes - Number of analog outputs (Obj:00, Var:221)" },
diff --git a/epan/dissectors/packet-dof.c b/epan/dissectors/packet-dof.c
index 99827d9475..eb169905fd 100644
--- a/epan/dissectors/packet-dof.c
+++ b/epan/dissectors/packet-dof.c
@@ -4793,13 +4793,13 @@ static void validate_c4(packet_info *pinfo, proto_item *pi, guint32 val, gint le
if (len > 1 && val < 0x80)
{
/* SPEC Type.3.1 Violation. */
- expert_add_info_format(pinfo, pi, &ei_c2_c3_c4_format, "DOF Violation: Type.3.1: Compressed 32-bit Compression Manditory.");
+ expert_add_info_format(pinfo, pi, &ei_c2_c3_c4_format, "DOF Violation: Type.3.1: Compressed 32-bit Compression Mandatory.");
}
if (len > 2 && val < 0x4000)
{
/* SPEC Type.3.1 Violation. */
- expert_add_info_format(pinfo, pi, &ei_c2_c3_c4_format, "DOF Violation: Type.3.1: Compressed 32-bit Compression Manditory.");
+ expert_add_info_format(pinfo, pi, &ei_c2_c3_c4_format, "DOF Violation: Type.3.1: Compressed 32-bit Compression Mandatory.");
}
}
@@ -4855,13 +4855,13 @@ static void validate_c3(packet_info *pinfo, proto_item *pi, guint32 val, gint le
if (len > 1 && val < 0x80)
{
/* SPEC Type.2.1 Violation. */
- expert_add_info_format(pinfo, pi, &ei_c2_c3_c4_format, "DOF Violation: Type.2.1: Compressed 24-bit Compression Manditory." );
+ expert_add_info_format(pinfo, pi, &ei_c2_c3_c4_format, "DOF Violation: Type.2.1: Compressed 24-bit Compression Mandatory." );
}
if (len > 2 && val < 0x4000)
{
/* SPEC Type.2.1 Violation. */
- expert_add_info_format(pinfo, pi, &ei_c2_c3_c4_format, "DOF Violation: Type.2.1: Compressed 24-bit Compression Manditory.");
+ expert_add_info_format(pinfo, pi, &ei_c2_c3_c4_format, "DOF Violation: Type.2.1: Compressed 24-bit Compression Mandatory.");
}
}
@@ -4905,7 +4905,7 @@ static void validate_c2(packet_info *pinfo, proto_item *pi, guint16 val, gint le
if (len > 1 && val < 0x80)
{
/* SPEC Type.1.1 Violation. */
- expert_add_info_format(pinfo, pi, &ei_c2_c3_c4_format, "DOF Violation: Type.1.1: Compressed 16-bit Compression Manditory." );
+ expert_add_info_format(pinfo, pi, &ei_c2_c3_c4_format, "DOF Violation: Type.1.1: Compressed 16-bit Compression Mandatory." );
}
}
diff --git a/epan/dissectors/packet-dsr.c b/epan/dissectors/packet-dsr.c
index 9065758933..9d75afac6e 100644
--- a/epan/dissectors/packet-dsr.c
+++ b/epan/dissectors/packet-dsr.c
@@ -697,10 +697,10 @@ proto_register_dsr(void)
NULL, HFILL }
},
{ &hf_dsr_opt_err_defaultflowunknown_dest,
- { "Original IP destination", "dsr.option.err.defaultflowunknow.dest",
+ { "Original IP destination", "dsr.option.err.defaultflowunknown.dest",
FT_IPv4, BASE_NONE,
NULL, 0x00,
- "Original IP destination address", HFILL }
+ NULL, HFILL }
},
};
diff --git a/epan/dissectors/packet-ethertype.c b/epan/dissectors/packet-ethertype.c
index 3c45b7e5e8..acf3c20b48 100644
--- a/epan/dissectors/packet-ethertype.c
+++ b/epan/dissectors/packet-ethertype.c
@@ -102,7 +102,7 @@ const value_string etype_vals[] = {
{ ETHERTYPE_PA_HBBACKUP, "PA HB Backup" },
{ ETHERTYPE_AVBTP, "IEEE 1722 Audio Video Bridging Transport Protocol" },
{ ETHERTYPE_ROHC, "Robust Header Compression(RoHC)" },
- { ETHERTYPE_TRILL, "TRansparent Interconnection of Lots of Links" },
+ { ETHERTYPE_TRILL, "Transparent Interconnection of Lots of Links" },
{ ETHERTYPE_L2ISIS, "Intermediate System to Intermediate System" },
{ ETHERTYPE_MAC_CONTROL, "MAC Control" },
{ ETHERTYPE_SLOW_PROTOCOLS, "Slow Protocols" },
diff --git a/epan/dissectors/packet-etsi_card_app_toolkit.c b/epan/dissectors/packet-etsi_card_app_toolkit.c
index b4b0a2c4c2..5da5e75526 100644
--- a/epan/dissectors/packet-etsi_card_app_toolkit.c
+++ b/epan/dissectors/packet-etsi_card_app_toolkit.c
@@ -233,7 +233,7 @@ static const value_string comp_tlv_tag_vals[] = {
{ 0x51, "Item text attribute list" },
{ 0x52, "3GPP PDP Context Activation parameter" },
{ 0x53, "Contactless state request" },
- { 0x54, "Conactless functionality state" },
+ { 0x54, "Contactless functionality state" },
{ 0x55, "3GPP CSG cell selection status" },
{ 0x56, "3GPP CSG ID" },
{ 0x57, "3GPP HNB name" },
@@ -2114,7 +2114,7 @@ proto_register_card_app_toolkit(void)
&ett_elem,
};
- proto_cat = proto_register_protocol("Card Application Tookit ETSI TS 102.223", "ETSI CAT",
+ proto_cat = proto_register_protocol("Card Application Toolkit ETSI TS 102.223", "ETSI CAT",
"etsi_cat");
proto_register_field_array(proto_cat, hf, array_length(hf));
diff --git a/epan/dissectors/packet-fcsb3.c b/epan/dissectors/packet-fcsb3.c
index 48ac4a8c8c..5c96627954 100644
--- a/epan/dissectors/packet-fcsb3.c
+++ b/epan/dissectors/packet-fcsb3.c
@@ -894,7 +894,7 @@ proto_register_fcsbccs (void)
NULL, HFILL}},
{ &hf_sbccs_dib_lrjcode,
- { "LRJ Reaspn Code", "fcsb3.lrjcode",
+ { "LRJ Reason Code", "fcsb3.lrjcode",
FT_UINT8, BASE_HEX, VALS (fc_sbccs_dib_lrj_errcode_val), 0x7F,
NULL, HFILL}},
diff --git a/epan/dissectors/packet-fmp_notify.c b/epan/dissectors/packet-fmp_notify.c
index 2dbb2857d6..87b3406965 100644
--- a/epan/dissectors/packet-fmp_notify.c
+++ b/epan/dissectors/packet-fmp_notify.c
@@ -591,7 +591,7 @@ proto_register_fmp_notify(void)
};
proto_fmp_notify =
- proto_register_protocol("File Mapping Protocol Nofity",
+ proto_register_protocol("File Mapping Protocol Notify",
"FMP/NOTIFY", "fmp_notify");
proto_register_field_array(proto_fmp_notify, hf, array_length(hf));
proto_register_subtree_array(ett, array_length(ett));
diff --git a/epan/dissectors/packet-forces.c b/epan/dissectors/packet-forces.c
index 31e6415391..2298417f8d 100644
--- a/epan/dissectors/packet-forces.c
+++ b/epan/dissectors/packet-forces.c
@@ -822,7 +822,7 @@ proto_register_forces(void)
10, &forces_alternate_sctp_high_prio_channel_port);
prefs_register_uint_preference(forces_module, "sctp_med_prio_port",
- "SCTP Meidium Priority channel port",
+ "SCTP Medium Priority channel port",
"Decode packets on this sctp port as ForCES",
10, &forces_alternate_sctp_med_prio_channel_port);
diff --git a/epan/dissectors/packet-gbcs.c b/epan/dissectors/packet-gbcs.c
index b2e15ed090..4b3c00b312 100644
--- a/epan/dissectors/packet-gbcs.c
+++ b/epan/dissectors/packet-gbcs.c
@@ -310,14 +310,14 @@ dlms_date_time(tvbuff_t *tvb, guint offset, nstime_t *date_time)
#define GBCS_GBZ_EXTENDED_HEADER_CONTROL_ENCRYPTED_COMPONENT 0x02
#define gbcs_gbz_alert_code_names_VALUE_STRING_LIST(XXX) \
- XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_ABOVE_AVERAGE_RMS_OVER_VOL_1,0x8002, "Average RMS Voltage above Average RMS Over Voltage Threshold (current value above threshold; previous value below threhsold)") \
- XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_ABOVE_AVERAGE_RMS_OVER_VOL_2,0x8003, "Average RMS Voltage above Average RMS Over Voltage Threshold on Phase 1 (current value above threshold; previous value below threhsold)") \
- XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_ABOVE_AVERAGE_RMS_OVER_VOL_3,0x8004, "Average RMS Voltage above Average RMS Over Voltage Threshold on Phase 2 (current value above threshold; previous value below threhsold)") \
- XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_ABOVE_AVERAGE_RMS_OVER_VOL_4,0x8005, "Average RMS Voltage above Average RMS Over Voltage Threshold on Phase 3 (current value above threshold; previous value below threhsold)") \
- XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_BELOW_AVERAGE_RMS_UNDER_VO_1,0x8006, "Average RMS Voltage below Average RMS Under Voltage Threshold (current value below threshold; previous value above threhsold)") \
- XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_BELOW_AVERAGE_RMS_UNDER_VO_2,0x8007, "Average RMS Voltage below Average RMS Under Voltage Threshold on Phase 1 (current value below threshold; previous value above threhsold)") \
- XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_BELOW_AVERAGE_RMS_UNDER_VO_3,0x8008, "Average RMS Voltage below Average RMS Under Voltage Threshold on Phase 2 (current value below threshold; previous value above threhsold)") \
- XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_BELOW_AVERAGE_RMS_UNDER_VO_4,0x8009, "Average RMS Voltage below Average RMS Under Voltage Threshold on Phase 3 (current value below threshold; previous value above threhsold)") \
+ XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_ABOVE_AVERAGE_RMS_OVER_VOL_1,0x8002, "Average RMS Voltage above Average RMS Over Voltage Threshold (current value above threshold; previous value below threshold)") \
+ XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_ABOVE_AVERAGE_RMS_OVER_VOL_2,0x8003, "Average RMS Voltage above Average RMS Over Voltage Threshold on Phase 1 (current value above threshold; previous value below threshold)") \
+ XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_ABOVE_AVERAGE_RMS_OVER_VOL_3,0x8004, "Average RMS Voltage above Average RMS Over Voltage Threshold on Phase 2 (current value above threshold; previous value below threshold)") \
+ XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_ABOVE_AVERAGE_RMS_OVER_VOL_4,0x8005, "Average RMS Voltage above Average RMS Over Voltage Threshold on Phase 3 (current value above threshold; previous value below threshold)") \
+ XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_BELOW_AVERAGE_RMS_UNDER_VO_1,0x8006, "Average RMS Voltage below Average RMS Under Voltage Threshold (current value below threshold; previous value above threshold)") \
+ XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_BELOW_AVERAGE_RMS_UNDER_VO_2,0x8007, "Average RMS Voltage below Average RMS Under Voltage Threshold on Phase 1 (current value below threshold; previous value above threshold)") \
+ XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_BELOW_AVERAGE_RMS_UNDER_VO_3,0x8008, "Average RMS Voltage below Average RMS Under Voltage Threshold on Phase 2 (current value below threshold; previous value above threshold)") \
+ XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_BELOW_AVERAGE_RMS_UNDER_VO_4,0x8009, "Average RMS Voltage below Average RMS Under Voltage Threshold on Phase 3 (current value below threshold; previous value above threshold)") \
XXX(GBCS_GBZ_ALERT_OVER_CURRENT, 0x8010, "Over Current") \
XXX(GBCS_GBZ_ALERT_OVER_CURRENT_L1, 0x8011, "Over Current L1") \
XXX(GBCS_GBZ_ALERT_OVER_CURRENT_L3, 0x8013, "Over Current L3") \
@@ -341,14 +341,14 @@ dlms_date_time(tvbuff_t *tvb, guint offset, nstime_t *date_time)
XXX(GBCS_GBZ_ALERT_RMS_VOLTAGE_BELOW_VOLTAGE_SAG_THRESHOLD_ON_PHA_2,0x802E, "RMS Voltage below Voltage Sag Threshold on Phase 2 (voltage falls below for longer than the configurable period)") \
XXX(GBCS_GBZ_ALERT_RMS_VOLTAGE_BELOW_VOLTAGE_SAG_THRESHOLD_ON_PHA_3,0x802F, "RMS Voltage below Voltage Sag Threshold on Phase 3 (voltage falls below for longer than the configurable period)") \
XXX(GBCS_GBZ_ALERT_GPF_DEVICE_LOG_CHANGED, 0x8071, "GPF Device Log Changed") \
- XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_BELOW_AVERAGE_RMS_OVER_VOL_1,0x8085, "Average RMS Voltage below Average RMS Over Voltage Threshold (current value below threshold; previous value above threhsold)") \
- XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_BELOW_AVERAGE_RMS_OVER_VOL_2,0x8086, "Average RMS Voltage below Average RMS Over Voltage Threshold on Phase 1 (current value below threshold; previous value above threhsold)") \
- XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_BELOW_AVERAGE_RMS_OVER_VOL_3,0x8087, "Average RMS Voltage below Average RMS Over Voltage Threshold on Phase 2 (current value below threshold; previous value above threhsold)") \
- XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_BELOW_AVERAGE_RMS_OVER_VOL_4,0x8088, "Average RMS Voltage below Average RMS Over Voltage Threshold on Phase 3 (current value below threshold; previous value above threhsold)") \
- XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_ABOVE_AVERAGE_RMS_UNDER_VO_1,0x8089, "Average RMS Voltage above Average RMS Under Voltage Threshold (current value above threshold; previous value below threhsold)") \
- XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_ABOVE_AVERAGE_RMS_UNDER_VO_2,0x808A, "Average RMS Voltage above Average RMS Under Voltage Threshold on Phase 1 (current value above threshold; previous value below threhsold)") \
- XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_ABOVE_AVERAGE_RMS_UNDER_VO_3,0x808B, "Average RMS Voltage above Average RMS Under Voltage Threshold on Phase 2 (current value above threshold; previous value below threhsold)") \
- XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_ABOVE_AVERAGE_RMS_UNDER_VO_4,0x808C, "Average RMS Voltage above Average RMS Under Voltage Threshold on Phase 3 (current value above threshold; previous value below threhsold)") \
+ XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_BELOW_AVERAGE_RMS_OVER_VOL_1,0x8085, "Average RMS Voltage below Average RMS Over Voltage Threshold (current value below threshold; previous value above threshold)") \
+ XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_BELOW_AVERAGE_RMS_OVER_VOL_2,0x8086, "Average RMS Voltage below Average RMS Over Voltage Threshold on Phase 1 (current value below threshold; previous value above threshold)") \
+ XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_BELOW_AVERAGE_RMS_OVER_VOL_3,0x8087, "Average RMS Voltage below Average RMS Over Voltage Threshold on Phase 2 (current value below threshold; previous value above threshold)") \
+ XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_BELOW_AVERAGE_RMS_OVER_VOL_4,0x8088, "Average RMS Voltage below Average RMS Over Voltage Threshold on Phase 3 (current value below threshold; previous value above threshold)") \
+ XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_ABOVE_AVERAGE_RMS_UNDER_VO_1,0x8089, "Average RMS Voltage above Average RMS Under Voltage Threshold (current value above threshold; previous value below threshold)") \
+ XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_ABOVE_AVERAGE_RMS_UNDER_VO_2,0x808A, "Average RMS Voltage above Average RMS Under Voltage Threshold on Phase 1 (current value above threshold; previous value below threshold)") \
+ XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_ABOVE_AVERAGE_RMS_UNDER_VO_3,0x808B, "Average RMS Voltage above Average RMS Under Voltage Threshold on Phase 2 (current value above threshold; previous value below threshold)") \
+ XXX(GBCS_GBZ_ALERT_AVERAGE_RMS_VOLTAGE_ABOVE_AVERAGE_RMS_UNDER_VO_4,0x808C, "Average RMS Voltage above Average RMS Under Voltage Threshold on Phase 3 (current value above threshold; previous value below threshold)") \
XXX(GBCS_GBZ_ALERT_RMS_VOLTAGE_ABOVE_EXTREME_OVER_VOLTAGE_THRESHO_5,0x808D, "RMS Voltage above Extreme Over Voltage Threshold (voltage returns below for longer than the configurable period)") \
XXX(GBCS_GBZ_ALERT_RMS_VOLTAGE_ABOVE_EXTREME_OVER_VOLTAGE_THRESHO_6,0x808E, "RMS Voltage above Extreme Over Voltage Threshold on Phase 1 (voltage returns below for longer than the configurable period)") \
XXX(GBCS_GBZ_ALERT_RMS_VOLTAGE_ABOVE_EXTREME_OVER_VOLTAGE_THRESHO_7,0x808F, "RMS Voltage above Extreme Over Voltage Threshold on Phase 2 (voltage returns below for longer than the configurable period)") \
diff --git a/epan/dissectors/packet-gelf.c b/epan/dissectors/packet-gelf.c
index 35456479dc..5642cee747 100644
--- a/epan/dissectors/packet-gelf.c
+++ b/epan/dissectors/packet-gelf.c
@@ -22,7 +22,7 @@
/* not sure if this really used
seen this here: https://github.com/lusis/gelfd/blob/229cf5f1f913a35db648b195300d1aaae841d522/lib/gelfd.rb#L7 */
#define HEADER_UNCOMPRESSED 0x1f3c
-#define HEADER_UNCOMPRESSED_PLAIN 0x7b22 // {", json payload without real header
+#define HEADER_UNCOMPRESSED_PLAIN 0x7b22 // json payload without real header
/* minimal size of json message with only required fields */
#define MIN_PLAIN_MSG 48
diff --git a/epan/dissectors/packet-geonw.c b/epan/dissectors/packet-geonw.c
index 58e13755f5..476e7b2561 100644
--- a/epan/dissectors/packet-geonw.c
+++ b/epan/dissectors/packet-geonw.c
@@ -296,8 +296,8 @@ static const value_string ch_header_type_names[] = {
{ HTST_GBC_CIRCLE, "Geo-scoped Broadcast Circular area" },
{ HTST_GBC_RECT, "Geo-scoped Broadcast Rectangular area" },
{ HTST_GBC_ELLIPSE, "Geo-scoped Broadcast Ellipsoidal area" },
- { HTST_TSB_SINGLE, "Topologucally-scoped broadcast Single-hop broadcast (SHB)" },
- { HTST_TSB_MULT, "Topologucally-scoped broadcast Multi-hop broadcast (TSB)" },
+ { HTST_TSB_SINGLE, "Topologically-scoped broadcast Single-hop broadcast (SHB)" },
+ { HTST_TSB_MULT, "Topologically-scoped broadcast Multi-hop broadcast (TSB)" },
{ HTST_LS_REQUEST, "Location Service Request" },
{ HTST_LS_REPLY, "Location Service Reply" },
{ 0x00, NULL}
diff --git a/epan/dissectors/packet-gmr1_rr.c b/epan/dissectors/packet-gmr1_rr.c
index 79cec5d0ca..52fb29a5d7 100644
--- a/epan/dissectors/packet-gmr1_rr.c
+++ b/epan/dissectors/packet-gmr1_rr.c
@@ -349,7 +349,7 @@ static const value_string rr_ciph_mode_setting_algo_vals[] = {
{ 4, "A5/5" },
{ 5, "A5/6" },
{ 6, "A5/7" },
- { 7, "Reverved" },
+ { 7, "Reserved" },
{ 0, NULL }
};
@@ -979,9 +979,9 @@ GMR1_IE_FUNC(gmr1_ie_rr_pkt_freq_prm)
/* [3] 11.5.2.107 - Packet Imm. Ass. Type 2 Params */
static const value_string rr_pkt_imm_ass_2_prm_ac_mac_mode_vals[] = {
{ 0, "Dynamic allocation" },
- { 1, "Reverved" },
- { 2, "Reverved" },
- { 3, "Reverved" },
+ { 1, "Reserved" },
+ { 2, "Reserved" },
+ { 3, "Reserved" },
{ 0, NULL }
};
diff --git a/epan/dissectors/packet-gre.c b/epan/dissectors/packet-gre.c
index b0870d47b5..3d6e072057 100644
--- a/epan/dissectors/packet-gre.c
+++ b/epan/dissectors/packet-gre.c
@@ -64,14 +64,14 @@ static int hf_gre_routing_sre_offset = -1;
static int hf_gre_routing_information = -1;
/* Ref 3GPP2 A.S0012-C v2.0 and A.S0008-A v1.0 */
-static int hf_gre_3ggp2_attrib = -1;
-static int hf_gre_3ggp2_attrib_id = -1;
-static int hf_gre_3ggp2_attrib_length = -1;
-static int hf_gre_3ggp2_sdi = -1;
-static int hf_gre_3ggp2_fci = -1;
-static int hf_gre_3ggp2_di = -1;
-static int hf_gre_3ggp2_flow_disc = -1;
-static int hf_gre_3ggp2_seg = -1;
+static int hf_gre_3gpp2_attrib = -1;
+static int hf_gre_3gpp2_attrib_id = -1;
+static int hf_gre_3gpp2_attrib_length = -1;
+static int hf_gre_3gpp2_sdi = -1;
+static int hf_gre_3gpp2_fci = -1;
+static int hf_gre_3gpp2_di = -1;
+static int hf_gre_3gpp2_flow_disc = -1;
+static int hf_gre_3gpp2_seg = -1;
static int hf_gre_wccp_redirect_header = -1;
static int hf_gre_wccp_dynamic_service = -1;
@@ -152,7 +152,7 @@ const value_string gre_typevals[] = {
#define ID_3GPP2_FLOW_DISCRIMINATOR 3
#define ID_3GPP2_SEG 4
-static const value_string gre_3ggp2_seg_vals[] = {
+static const value_string gre_3gpp2_seg_vals[] = {
{ 0x00, "Packet Started" },
{ 0x01, "Packet continued" },
{ 0x02, "Packet Ended" },
@@ -161,7 +161,7 @@ static const value_string gre_3ggp2_seg_vals[] = {
/* 3GPP2 A.S0012-C v2.0
* 2.6.1 GRE Attributes
*/
-static const value_string gre_3ggp2_attrib_id_vals[] = {
+static const value_string gre_3gpp2_attrib_id_vals[] = {
{ 0x01, "1x SDB/HRPD DOS Indicator" },
{ 0x02, "Flow Control Indication" },
/* A.S0008-A v1.0 */
@@ -170,17 +170,17 @@ static const value_string gre_3ggp2_attrib_id_vals[] = {
{ 0, NULL }
};
-static const true_false_string gre_3ggp2_sdi_val = {
+static const true_false_string gre_3gpp2_sdi_val = {
"Packet suitable for 1x SDB or HRPD DOS transmission",
"Reserved"
};
-static const true_false_string gre_3ggp2_fci_val = {
+static const true_false_string gre_3gpp2_fci_val = {
"XOFF",
"XON"
};
-static const true_false_string gre_3ggp2_di_val = {
+static const true_false_string gre_3gpp2_di_val = {
"INDEFINITE:",
"TEMPORARY"
};
@@ -210,7 +210,7 @@ dissect_gre_3gpp2_attribs(tvbuff_t *tvb, int offset, proto_tree *tree)
guint8 value;
int start_offset = offset;
- proto_item *ti = proto_tree_add_item(tree, hf_gre_3ggp2_attrib, tvb, offset, 0, ENC_NA);
+ proto_item *ti = proto_tree_add_item(tree, hf_gre_3gpp2_attrib, tvb, offset, 0, ENC_NA);
proto_tree *atree = proto_item_add_subtree(ti, ett_3gpp2_attribs);
while(last_attrib != TRUE)
@@ -219,10 +219,10 @@ dissect_gre_3gpp2_attribs(tvbuff_t *tvb, int offset, proto_tree *tree)
guint8 attrib_length = tvb_get_guint8(tvb, offset + 1);
attr_tree = proto_tree_add_subtree(atree, tvb, offset, attrib_length + 1 + 1, ett_3gpp2_attr, &attr_item,
- val_to_str((attrib_id&0x7f), gre_3ggp2_attrib_id_vals, "%u (Unknown)"));
+ val_to_str((attrib_id&0x7f), gre_3gpp2_attrib_id_vals, "%u (Unknown)"));
- proto_tree_add_item(attr_tree, hf_gre_3ggp2_attrib_id, tvb, offset, 1, ENC_BIG_ENDIAN);
- proto_tree_add_item(attr_tree, hf_gre_3ggp2_attrib_length, tvb, offset+1, 1, ENC_BIG_ENDIAN);
+ proto_tree_add_item(attr_tree, hf_gre_3gpp2_attrib_id, tvb, offset, 1, ENC_BIG_ENDIAN);
+ proto_tree_add_item(attr_tree, hf_gre_3gpp2_attrib_length, tvb, offset+1, 1, ENC_BIG_ENDIAN);
offset += 2;
last_attrib = (attrib_id & 0x80)?TRUE:FALSE;
@@ -233,14 +233,14 @@ dissect_gre_3gpp2_attribs(tvbuff_t *tvb, int offset, proto_tree *tree)
case ID_3GPP2_FLOW_DISCRIMINATOR:
{
value = tvb_get_guint8(tvb,offset);
- proto_tree_add_item(attr_tree, hf_gre_3ggp2_flow_disc, tvb, offset, attrib_length, ENC_NA);
+ proto_tree_add_item(attr_tree, hf_gre_3gpp2_flow_disc, tvb, offset, attrib_length, ENC_NA);
proto_item_append_text(attr_item," - 0x%x",value);
}
break;
case ID_3GPP2_SDI_FLAG:
{
value = tvb_get_guint8(tvb,offset);
- proto_tree_add_item(attr_tree, hf_gre_3ggp2_sdi, tvb, offset, attrib_length, ENC_BIG_ENDIAN);
+ proto_tree_add_item(attr_tree, hf_gre_3gpp2_sdi, tvb, offset, attrib_length, ENC_BIG_ENDIAN);
proto_item_append_text(attr_item," - %s",
(value & 0x80) ? "Packet suitable for 1x SDB or HRPD DOS transmission" : "Reserved");
@@ -249,17 +249,17 @@ dissect_gre_3gpp2_attribs(tvbuff_t *tvb, int offset, proto_tree *tree)
case ID_3GPP2_SEG:
{
value = tvb_get_guint8(tvb,offset) >>6;
- proto_tree_add_item(attr_tree, hf_gre_3ggp2_seg, tvb, offset, attrib_length, ENC_BIG_ENDIAN);
- proto_item_append_text(attr_item," - %s",val_to_str(value, gre_3ggp2_seg_vals, "0x%02X - Unknown"));
+ proto_tree_add_item(attr_tree, hf_gre_3gpp2_seg, tvb, offset, attrib_length, ENC_BIG_ENDIAN);
+ proto_item_append_text(attr_item," - %s",val_to_str(value, gre_3gpp2_seg_vals, "0x%02X - Unknown"));
}
break;
case ID_3GPP2_FLOW_CTRL:
{
value = tvb_get_guint8(tvb,offset);
- proto_tree_add_item(attr_tree, hf_gre_3ggp2_fci, tvb, offset, attrib_length, ENC_BIG_ENDIAN);
+ proto_tree_add_item(attr_tree, hf_gre_3gpp2_fci, tvb, offset, attrib_length, ENC_BIG_ENDIAN);
proto_item_append_text(attr_item," - %s",
(value & 0x80) ? "XON" : "XOFF");
- proto_tree_add_item(attr_tree, hf_gre_3ggp2_di, tvb, offset, attrib_length, ENC_BIG_ENDIAN);
+ proto_tree_add_item(attr_tree, hf_gre_3gpp2_di, tvb, offset, attrib_length, ENC_BIG_ENDIAN);
proto_item_append_text(attr_item,"/%s",
(value & 0x40) ? "INDEFINITE" : "TEMPORARY");
}
@@ -624,44 +624,44 @@ proto_register_gre(void)
FT_BYTES, BASE_NONE, NULL, 0x0,
"The Routing Information field contains data which may be used in routing this packet", HFILL }
},
- { &hf_gre_3ggp2_attrib,
- { "3GGP2 Attributes", "gre.ggp2_attrib",
+ { &hf_gre_3gpp2_attrib,
+ { "3GPP2 Attributes", "gre.3gpp2_attrib",
FT_NONE, BASE_NONE, NULL, 0x0,
NULL, HFILL }
},
- { &hf_gre_3ggp2_attrib_id,
- { "Type", "gre.ggp2_attrib_id",
- FT_UINT8, BASE_HEX, VALS(gre_3ggp2_attrib_id_vals), 0x7f,
+ { &hf_gre_3gpp2_attrib_id,
+ { "Type", "gre.3gpp2_attrib_id",
+ FT_UINT8, BASE_HEX, VALS(gre_3gpp2_attrib_id_vals), 0x7f,
NULL, HFILL }
},
- { &hf_gre_3ggp2_attrib_length,
- { "Length", "gre.ggp2_attrib_length",
+ { &hf_gre_3gpp2_attrib_length,
+ { "Length", "gre.3gpp2_attrib_length",
FT_UINT8, BASE_HEX, NULL, 0x0,
NULL, HFILL }
},
- { &hf_gre_3ggp2_sdi,
- { "SDI/DOS", "gre.3ggp2_sdi",
- FT_BOOLEAN, 16, TFS(&gre_3ggp2_sdi_val), 0x8000,
+ { &hf_gre_3gpp2_sdi,
+ { "SDI/DOS", "gre.3gpp2_sdi",
+ FT_BOOLEAN, 16, TFS(&gre_3gpp2_sdi_val), 0x8000,
"Short Data Indicator(SDI)/Data Over Signaling (DOS)", HFILL }
},
- { &hf_gre_3ggp2_fci,
- { "Flow Control Indicator", "gre.3ggp2_fci",
- FT_BOOLEAN, 16, TFS(&gre_3ggp2_fci_val), 0x8000,
+ { &hf_gre_3gpp2_fci,
+ { "Flow Control Indicator", "gre.3gpp2_fci",
+ FT_BOOLEAN, 16, TFS(&gre_3gpp2_fci_val), 0x8000,
NULL, HFILL }
},
- { &hf_gre_3ggp2_di,
- { "Duration Indicator", "gre.3ggp2_di",
- FT_BOOLEAN, 16, TFS(&gre_3ggp2_di_val), 0x4000,
+ { &hf_gre_3gpp2_di,
+ { "Duration Indicator", "gre.3gpp2_di",
+ FT_BOOLEAN, 16, TFS(&gre_3gpp2_di_val), 0x4000,
NULL, HFILL }
},
- { &hf_gre_3ggp2_flow_disc,
+ { &hf_gre_3gpp2_flow_disc,
{ "Flow ID", "gre.ggp2_flow_disc",
FT_BYTES, BASE_NONE, NULL, 0x0,
NULL, HFILL }
},
- { &hf_gre_3ggp2_seg,
- { "Type", "gre.ggp2_3ggp2_seg",
- FT_UINT16, BASE_HEX, VALS(gre_3ggp2_seg_vals), 0xc000,
+ { &hf_gre_3gpp2_seg,
+ { "Type", "gre.ggp2_3gpp2_seg",
+ FT_UINT16, BASE_HEX, VALS(gre_3gpp2_seg_vals), 0xc000,
NULL, HFILL }
},
diff --git a/epan/dissectors/packet-gsm_abis_om2000.c b/epan/dissectors/packet-gsm_abis_om2000.c
index 836d23dfbf..c88b42d7b3 100644
--- a/epan/dissectors/packet-gsm_abis_om2000.c
+++ b/epan/dissectors/packet-gsm_abis_om2000.c
@@ -149,7 +149,7 @@ static const value_string om2k_msgcode_vals[] = {
{ 0x001a, "CON Configuration Result" },
{ 0x001c, "Connect Command" },
{ 0x001e, "Connect Complete" },
- { 0x001f, "Connect Rejecte" },
+ { 0x001f, "Connect Reject" },
{ 0x0028, "Disable Request" },
{ 0x002a, "Disable Request Accept" },
{ 0x002b, "Disable Request Reject" },
@@ -619,7 +619,7 @@ static const value_string om2k_res_code_vals[] = {
{ 0x06, "Protocol error" },
{ 0x07, "MO not connected" },
{ 0x08, "Parameter error" },
- { 0x09, "Operational functio not supported" },
+ { 0x09, "Operational function not supported" },
{ 0x0a, "Local Access state LOCALLY DISCONNECTED" },
{ 0, NULL }
};
@@ -641,10 +641,10 @@ dissect_tss_mo_state(tvbuff_t *tvb, gint offset, proto_tree *tree)
for (i = 0; i < 8; i+= 2) {
tmp = tvb_get_guint8(tvb, offset);
proto_tree_add_uint_format(tree, hf_om2k_tsn_state, tvb, offset, 1, tmp & 0xf,
- "Timslot %u MO State: %s", i,
+ "Timeslot %u MO State: %s", i,
val_to_str(tmp & 0xf, om2k_mo_state_vals, "unknown (%02d)"));
proto_tree_add_uint_format(tree, hf_om2k_tsn_state, tvb, offset, 1, tmp >> 4,
- "Timslot %u MO State: %s", i+1,
+ "Timeslot %u MO State: %s", i+1,
val_to_str(tmp >> 4, om2k_mo_state_vals, "unknown (%02d)"));
offset++;
}
@@ -1356,7 +1356,7 @@ proto_register_abis_om2000(void)
{ &hf_om2k_maio,
{ "MAIO", "gsm_abis_om2000.maio",
FT_UINT8, BASE_DEC, NULL, 0,
- "Mobile Allication Index Offset", HFILL }
+ "Mobile Allocation Index Offset", HFILL }
},
{ &hf_om2k_bsic,
{ "BSIC", "gsm_abis_om2000.bsic",
diff --git a/epan/dissectors/packet-gsm_abis_oml.c b/epan/dissectors/packet-gsm_abis_oml.c
index ab7389b15d..594f62e93e 100644
--- a/epan/dissectors/packet-gsm_abis_oml.c
+++ b/epan/dissectors/packet-gsm_abis_oml.c
@@ -1060,7 +1060,7 @@ static const value_string oml_fom_attr_vals_bs11[] = {
{ NM_ATT_BS11_LMT_USER_NAME, "SIE LMT User Account Name" },
{ NM_ATT_BS11_L1_CONTROL_TS, "SIE L1 Control TS" },
{ NM_ATT_BS11_RADIO_MEAS_GRAN, "SIE Radio Measurement Granularity" },
- { NM_ATT_BS11_RADIO_MEAS_REP, "SIE Rdadio Measurement Report" },
+ { NM_ATT_BS11_RADIO_MEAS_REP, "SIE Radio Measurement Report" },
{ NM_ATT_BS11_SH_LAPD_INT_TIMER,"SIE LAPD Internal Timer" },
{ NM_ATT_BS11_BTS_STATE, "SIE BTS State" },
{ NM_ATT_BS11_E1_STATE, "SIE E1 State" },
@@ -1091,7 +1091,7 @@ static const value_string oml_fom_attr_vals_bs11[] = {
/* proprietary ip.access attributes, not in the standard */
static const value_string oml_fom_attr_vals_ipa[] = {
{ NM_ATT_IPACC_DST_IP, "IPA Destination IP Address" },
- { NM_ATT_IPACC_DST_IP_PORT, "IPA Destionation IP Port" },
+ { NM_ATT_IPACC_DST_IP_PORT, "IPA Destination IP Port" },
{ NM_ATT_IPACC_SSRC, "IPA RTP SSRC" },
{ NM_ATT_IPACC_RTP_PAYLD_TYPE, "IPA RTP Payload Type" },
{ NM_ATT_IPACC_BASEB_ID, "IPA Baseband Identifier" },
@@ -1294,7 +1294,7 @@ static const value_string oml_nack_cause[] = {
{ NM_NACK_PHYSCFG_NOTRESTORE, "Phys config cannot be restored" },
{ NM_NACK_TEST_NOSUCH, "No such Test" },
{ NM_NACK_TEST_NOSTOP, "Test cannot be stopped" },
- { NM_NACK_MSGINCONSIST_PHYSCFG, "Message inconsisten with physical config" },
+ { NM_NACK_MSGINCONSIST_PHYSCFG, "Message inconsistent with physical config" },
{ NM_NACK_FILE_INCOMPLETE, "Complete file not received" },
{ NM_NACK_FILE_NOTAVAIL, "File not available at destination" },
{ NM_NACK_FILE_NOTACTIVATE, "File cannot be activated" },
@@ -2103,7 +2103,7 @@ proto_register_abis_oml(void)
{ "Primary OML TCP Port",
"gsm_abis_oml.fom.attr.ipa.prim_oml_port",
FT_UINT16, BASE_DEC, NULL, 0,
- "TCP Port of the BSC for the primarly OML link",
+ "TCP Port of the BSC for the primary OML link",
HFILL }
},
{ &hf_attr_ipa_location_name,
diff --git a/epan/dissectors/packet-gsm_abis_pgsl.c b/epan/dissectors/packet-gsm_abis_pgsl.c
index d1e4ad9f42..01667cc3e6 100644
--- a/epan/dissectors/packet-gsm_abis_pgsl.c
+++ b/epan/dissectors/packet-gsm_abis_pgsl.c
@@ -123,7 +123,7 @@ static const value_string pgsl_cs_vals[] = {
static const value_string pgsl_ucm_vals[] = {
{ 1, "Normal Burst (GSMK CS1/CS2/CS3/CS4)" },
{ 2, "Normal Burst (CS1 or MCS1 to MCS9)" },
- { 3, "Access Burst (8 bit, Traning Sequence 0)" },
+ { 3, "Access Burst (8 bit, Training Sequence 0)" },
{ 4, "Access Burst (8 bit or 11 bit, Training Sequence 0/1/2)" },
{ 0, NULL }
};
diff --git a/epan/dissectors/packet-gsm_bssmap_le.c b/epan/dissectors/packet-gsm_bssmap_le.c
index c9b0f09a10..c5d6241b81 100644
--- a/epan/dissectors/packet-gsm_bssmap_le.c
+++ b/epan/dissectors/packet-gsm_bssmap_le.c
@@ -458,7 +458,7 @@ static const value_string bssmap_le_position_method_failure_diagnostic_vals[] =
{ 5, "locationProcedureNotSupportedByTargetMS" },
{ 6, "qoSNotAttainable" },
{ 7, "positionMethodNotAvailableInNetwork" },
- { 8, "positionMethodNotAvailableInLocaitonArea" },
+ { 8, "positionMethodNotAvailableInLocationArea" },
{ 0, NULL}
};
static guint16
diff --git a/epan/dissectors/packet-gsm_cbch.c b/epan/dissectors/packet-gsm_cbch.c
index 8f876acb43..5ac5bde142 100644
--- a/epan/dissectors/packet-gsm_cbch.c
+++ b/epan/dissectors/packet-gsm_cbch.c
@@ -208,7 +208,7 @@ dissect_schedule_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *top_tree
if (octet1 == 0)
{
proto_tree_add_uint_format_value(sched_subtree, hf_gsm_cbch_slot, tvb, offset++, 1, new_slots[i],
- "%d, Repeat of non-existant slot %d",
+ "%d, Repeat of non-existent slot %d",
new_slots[i], octet1);
}
else if (octet1 < new_slots[i])
diff --git a/epan/dissectors/packet-gsm_rlcmac.c b/epan/dissectors/packet-gsm_rlcmac.c
index 0e28cd9b61..14fa86c4bf 100644
--- a/epan/dissectors/packet-gsm_rlcmac.c
+++ b/epan/dissectors/packet-gsm_rlcmac.c
@@ -12540,7 +12540,7 @@ proto_register_gsm_rlcmac(void)
}
},
{ &hf_fddarget_cell_t_bandwith_fdd,
- { "BANDWITH_FDD", "gsm_rlcmac.ul.epdan_bandwith_fdd",
+ { "BANDWIDTH_FDD", "gsm_rlcmac.ul.epdan_bandwidth_fdd",
FT_UINT8, BASE_DEC, NULL, 0x0,
NULL, HFILL
}
@@ -14567,7 +14567,7 @@ proto_register_gsm_rlcmac(void)
}
},
{ &hf_fdd_target_cell_notif_bandwith_fdd,
- { "BANDWITH_FDD", "gsm_rlcmac.dl.fdd_target_cell_notif_bandwith_fdd",
+ { "BANDWIDTH_FDD", "gsm_rlcmac.dl.fdd_target_cell_notif_bandwidth_fdd",
FT_UINT8, BASE_DEC, NULL, 0x0,
NULL, HFILL
}
@@ -15364,7 +15364,7 @@ proto_register_gsm_rlcmac(void)
},
#if 0
{ &hf_packet_non_gprs_cell_opt_ext_len,
- { "Extention_Length", "gsm_rlcmac.dl.non_gprs_cell_opt_extention_length",
+ { "Extension_Length", "gsm_rlcmac.dl.non_gprs_cell_opt_extension_length",
FT_UINT8, BASE_DEC, NULL, 0x0,
NULL, HFILL
}
@@ -15996,13 +15996,13 @@ proto_register_gsm_rlcmac(void)
}
},
{ &hf_fdd_target_cell_bandwith_fdd_exist,
- { "Exist_Bandwith_FDD", "gsm_rlcmac.fdd_target_cell.bandwith_fdd_exist",
+ { "Exist_Bandwidth_FDD", "gsm_rlcmac.fdd_target_cell.bandwidth_fdd_exist",
FT_UINT8, BASE_DEC, NULL, 0x0,
NULL, HFILL
}
},
{ &hf_tdd_target_cell_bandwith_tdd_exist,
- { "Exist_Bandwith_TDD", "gsm_rlcmac.tdd_target_cell.bandwith_tdd_exist",
+ { "Exist_Bandwidth_TDD", "gsm_rlcmac.tdd_target_cell.bandwidth_tdd_exist",
FT_UINT8, BASE_DEC, NULL, 0x0,
NULL, HFILL
}
@@ -16044,7 +16044,7 @@ proto_register_gsm_rlcmac(void)
}
},
{ &hf_pccf_additionsr5_g_rnti_extention_exist,
- { "Exist_G_RNTI_extention", "gsm_rlcmac.pccf_additionsr5.g_rnti_extention_exist",
+ { "Exist_G_RNTI_extension", "gsm_rlcmac.pccf_additionsr5.g_rnti_extension_exist",
FT_UINT8, BASE_DEC, NULL, 0x0,
NULL, HFILL
}
@@ -17226,7 +17226,7 @@ proto_register_gsm_rlcmac(void)
}
},
{ &hf_target_cell_3g_additionsr5_g_rnti_extention_exist,
- { "Exist_G_RNTI_Extention", "gsm_rlcmac.target_cell_3g_additionsr5.g_rnti_extention_exist",
+ { "Exist_G_RNTI_Extension", "gsm_rlcmac.target_cell_3g_additionsr5.g_rnti_extension_exist",
FT_UINT8, BASE_DEC, NULL, 0x0,
NULL, HFILL
}
@@ -17418,13 +17418,13 @@ proto_register_gsm_rlcmac(void)
}
},
{ &hf_fdd_target_cell_notif_bandwith_fdd_exist,
- { "Exist_Bandwith_FDD", "gsm_rlcmac.fdd_target_cell_notif.bandwith_fdd_exist",
+ { "Exist_Bandwidth_FDD", "gsm_rlcmac.fdd_target_cell_notif.bandwidth_fdd_exist",
FT_UINT8, BASE_DEC, NULL, 0x0,
NULL, HFILL
}
},
{ &hf_tdd_target_cell_notif_bandwith_tdd_exist,
- { "Exist_Bandwith_TDD", "gsm_rlcmac.tdd_target_cell_notif.bandwith_tdd_exist",
+ { "Exist_Bandwidth_TDD", "gsm_rlcmac.tdd_target_cell_notif.bandwidth_tdd_exist",
FT_UINT8, BASE_DEC, NULL, 0x0,
NULL, HFILL
}
diff --git a/epan/dissectors/packet-gsm_sim.c b/epan/dissectors/packet-gsm_sim.c
index 376ffeba6c..39e7b0eeb7 100644
--- a/epan/dissectors/packet-gsm_sim.c
+++ b/epan/dissectors/packet-gsm_sim.c
@@ -1655,7 +1655,7 @@ proto_register_gsm_sim(void)
{ &hf_tp_cb_data_dld,
{ "CB Data Download", "gsm_sim.tp.cb_data_dld",
FT_BOOLEAN, 8, TFS(&tfs_supported_not_supported), 0x04,
- "TP Cell Broadcast Data Downolad", HFILL }
+ "TP Cell Broadcast Data Download", HFILL }
},
{ &hf_tp_menu_sel,
{ "Menu Selection", "gsm_sim.tp.menu_sel",
diff --git a/epan/dissectors/packet-gtp.c b/epan/dissectors/packet-gtp.c
index 2c2b775748..1d58ca3aac 100644
--- a/epan/dissectors/packet-gtp.c
+++ b/epan/dissectors/packet-gtp.c
@@ -476,7 +476,7 @@ static expert_field ei_gtp_guaranteed_bit_rate_value = EI_INIT;
static expert_field ei_gtp_max_bit_rate_value = EI_INIT;
static expert_field ei_gtp_ext_geo_loc_type = EI_INIT;
static expert_field ei_gtp_iei = EI_INIT;
-static expert_field ei_gtp_unknown_extention_header = EI_INIT;
+static expert_field ei_gtp_unknown_extension_header = EI_INIT;
static expert_field ei_gtp_unknown_pdu_type = EI_INIT;
/* --- PDCP DECODE ADDITIONS --- */
@@ -8975,7 +8975,7 @@ static int
decode_gtp_unknown(tvbuff_t * tvb, int offset, packet_info * pinfo, proto_tree * tree, session_args_t * args _U_)
{
- proto_tree_add_expert(tree, pinfo, &ei_gtp_unknown_extention_header, tvb, offset, 1);
+ proto_tree_add_expert(tree, pinfo, &ei_gtp_unknown_extension_header, tvb, offset, 1);
return tvb_reported_length_remaining(tvb, offset);
}
@@ -11361,7 +11361,7 @@ proto_register_gtp(void)
{ &ei_gtp_max_bit_rate_value, { "gtp.max_bit_rate_value", PI_PROTOCOL, PI_NOTE, "Use the value indicated by the Maximum bit rate", EXPFILL }},
{ &ei_gtp_ext_geo_loc_type, { "gtp.ext_geo_loc_type.unknown", PI_PROTOCOL, PI_WARN, "Unknown Location type data", EXPFILL }},
{ &ei_gtp_iei, { "gtp.iei.unknown", PI_PROTOCOL, PI_WARN, "Unknown IEI - Later spec than TS 29.060 9.4.0 used?", EXPFILL }},
- { &ei_gtp_unknown_extention_header, { "gtp.unknown_extention_header", PI_PROTOCOL, PI_WARN, "Unknown extension header", EXPFILL }},
+ { &ei_gtp_unknown_extension_header, { "gtp.unknown_extension_header", PI_PROTOCOL, PI_WARN, "Unknown extension header", EXPFILL }},
{ &ei_gtp_unknown_pdu_type, { "gtp.unknown_pdu_type", PI_PROTOCOL, PI_WARN, "Unknown PDU type", EXPFILL }},
};
diff --git a/epan/dissectors/packet-gtpv2.c b/epan/dissectors/packet-gtpv2.c
index 92661dc81f..350851d66c 100644
--- a/epan/dissectors/packet-gtpv2.c
+++ b/epan/dissectors/packet-gtpv2.c
@@ -8783,7 +8783,7 @@ void proto_register_gtpv2(void)
NULL, HFILL}
},
{ &hf_gtpv2_msg_length,
- {"Message Length", "gtpv2.msg_lengt",
+ {"Message Length", "gtpv2.msg_length",
FT_UINT16, BASE_DEC, NULL, 0x0,
NULL, HFILL}
},
diff --git a/epan/dissectors/packet-homeplug-av.c b/epan/dissectors/packet-homeplug-av.c
index 5ec5262643..65f4fdb909 100644
--- a/epan/dissectors/packet-homeplug-av.c
+++ b/epan/dissectors/packet-homeplug-av.c
@@ -1182,7 +1182,7 @@ static const value_string homeplug_av_mmtype_general_vals[] = {
/* Station - Station */
{ HOMEPLUG_AV_MMTYPE_GENERAL_CM_UNASSOCIATED_STA_IND , "CM_UNASSOCIATED_STA.IND" },
{ HOMEPLUG_AV_MMTYPE_GENERAL_CM_ENCRYPTED_PAYLOAD_IND , "CM_ENCRYPTED_PAYLOAD.IND (Encrypted Payload Indicate)" },
- { HOMEPLUG_AV_MMTYPE_GENERAL_CM_ENCRYPTED_PAYLOAD_RSP , "CM_ENCRYPTED_PAYLOAD.RSP (Encrypted Payload Respons)" },
+ { HOMEPLUG_AV_MMTYPE_GENERAL_CM_ENCRYPTED_PAYLOAD_RSP , "CM_ENCRYPTED_PAYLOAD.RSP (Encrypted Payload Response)" },
{ HOMEPLUG_AV_MMTYPE_GENERAL_CM_SET_KEY_REQ , "CM_SET_KEY.REQ (Set Key Request)" },
{ HOMEPLUG_AV_MMTYPE_GENERAL_CM_SET_KEY_CNF , "CM_SET_KEY.CNF (Set Key Confirmation)" },
{ HOMEPLUG_AV_MMTYPE_GENERAL_CM_GET_KEY_REQ , "CM_GET_KEY.REQ (Get Key Request)" },
@@ -1294,7 +1294,7 @@ static const value_string homeplug_av_mmtype_qualcomm_vals[] = {
{ HOMEPLUG_AV_MMTYPE_QUALCOMM_SET_SDRAM_REQ, "SET_SDRAM.REQ (Set SDRAM Configuration Request)" },
{ HOMEPLUG_AV_MMTYPE_QUALCOMM_SET_SDRAM_CNF, "SET_SDRAM.CNF (Set SDRAM Configuration Confirmation)" },
{ HOMEPLUG_AV_MMTYPE_QUALCOMM_HOST_ACTION_IND, "HOST_ACTION.IND (Embedded Host Action Required Indication)" },
- { HOMEPLUG_AV_MMTYPE_QUALCOMM_HOST_ACTION_RSP, "HOST_ACTION.RSP (Embedded Host Action Required Respons)" },
+ { HOMEPLUG_AV_MMTYPE_QUALCOMM_HOST_ACTION_RSP, "HOST_ACTION.RSP (Embedded Host Action Required Response)" },
{ HOMEPLUG_AV_MMTYPE_QUALCOMM_OP_ATTR_REQ, "OP_ATTR.REQ (Get Device Attributes Request)" },
{ HOMEPLUG_AV_MMTYPE_QUALCOMM_OP_ATTR_CNF, "OP_ATTR.CNF (Get Device Attributes Confirmation)" },
{ HOMEPLUG_AV_MMTYPE_QUALCOMM_GET_ENET_PHY_REQ, "GET_ENET_PHY.REQ (Get Ethernet PHY Settings Request)" },
@@ -1486,7 +1486,7 @@ static value_string_ext homeplug_av_peks_vals_ext = VALUE_STRING_EXT_INIT(homepl
static const value_string homeplug_av_bcn_cco_cap_vals[] = {
{ 0x0, "CSMA-only (no QoS/TDMA)" },
{ 0x1, "Uncoordinated mode QoS/TDMA" },
- { 0x2, "Coordianted mode QoS/TDMA" },
+ { 0x2, "Coordinated mode QoS/TDMA" },
{ 0x3, "Reserved" },
{ 0, NULL }
};
@@ -2063,8 +2063,8 @@ static const value_string homeplug_av_coupling_vals[] = {
static const value_string homeplug_av_cc_assoc_result_vals[] = {
{ 0x00, "Success" },
- { 0x01, "Failure due to temporary resourse exhaustion, try again later" },
- { 0x02, "Failure due to permanent resourse exhaustion" },
+ { 0x01, "Failure due to temporary resource exhaustion, try again later" },
+ { 0x02, "Failure due to permanent resource exhaustion" },
{ 0x03, "Failure" },
{ 0, NULL }
};
@@ -2095,8 +2095,8 @@ static const value_string homeplug_av_gp_cm_slac_parm_sectype_vals[] = {
};
static const value_string homeplug_av_gp_cm_slac_parm_resptype_vals[] = {
- { 0x00, "Not Transmited to other GP STA's HLE" },
- { 0x01, "Transmited to another GP STA's HLE" },
+ { 0x00, "Not Transmitted to other GP STA's HLE" },
+ { 0x01, "Transmitted to another GP STA's HLE" },
{ 0, NULL }
};
@@ -2133,7 +2133,7 @@ static const value_string homeplug_av_gp_cm_slac_user_data_broadcast_vals[] = {
#define HOMEPLUG_AV_GP_CM_SLAC_USER_DATA_TLV_TYPE_VENDOR_RESERVED 0x1F
static const value_string homeplug_av_gp_cm_slac_user_data_tlv_types_vals[] = {
- { HOMEPLUG_AV_GP_CM_SLAC_USER_DATA_TLV_TYPE_VENDOR_RESERVED, "Vender Reserved" },
+ { HOMEPLUG_AV_GP_CM_SLAC_USER_DATA_TLV_TYPE_VENDOR_RESERVED, "Vendor Reserved" },
{ 0, NULL }
};
@@ -6423,7 +6423,7 @@ proto_register_homeplug_av(void)
FT_UINT8, BASE_DEC, VALS(homeplug_av_bcn_cco_cap_vals), HOMEPLUG_AV_CCO_CAP_MASK, NULL, HFILL }
},
{ &hf_homeplug_av_bcn_rsf,
- { "Resuable SNID?", "homeplug_av.bcn.rsf",
+ { "Reusable SNID?", "homeplug_av.bcn.rsf",
FT_BOOLEAN, 8, NULL, HOMEPLUG_AV_RSF_MASK, NULL, HFILL }
},
{ &hf_homeplug_av_bcn_plevel,
@@ -6622,7 +6622,7 @@ proto_register_homeplug_av(void)
FT_BOOLEAN, BASE_NONE, NULL, 0x00, NULL, HFILL }
},
{ &hf_homeplug_av_brg_infos_cnf_btei,
- { "Bridge Terminal Equipement Identifier", "homeplug_av.brg_infos_cnf.btei",
+ { "Bridge Terminal Equipment Identifier", "homeplug_av.brg_infos_cnf.btei",
FT_UINT8, BASE_DEC, NULL, 0x00, NULL, HFILL }
},
{ &hf_homeplug_av_brg_infos_cnf_num_stas,
@@ -7090,7 +7090,7 @@ proto_register_homeplug_av(void)
FT_UINT8, BASE_HEX, NULL, 0x00, NULL, HFILL }
},
{ &hf_homeplug_av_nw_info_tei,
- { "Terminal Equipement Identifier", "homeplug_av.nw_info.tei",
+ { "Terminal Equipment Identifier", "homeplug_av.nw_info.tei",
FT_UINT8, BASE_DEC, NULL, 0x00, NULL, HFILL }
},
{ &hf_homeplug_av_nw_info_sta_role,
@@ -7102,7 +7102,7 @@ proto_register_homeplug_av(void)
FT_ETHER, BASE_NONE, NULL, 0x00, NULL, HFILL }
},
{ &hf_homeplug_av_nw_info_cco_tei,
- { "CCo Terminal Equipement Identifier", "homeplug_av.nw_info_cnf.cco_tei",
+ { "CCo Terminal Equipment Identifier", "homeplug_av.nw_info_cnf.cco_tei",
FT_UINT8, BASE_DEC, NULL, 0x00, NULL, HFILL }
},
{ &hf_homeplug_av_nw_info_num_stas,
@@ -7127,7 +7127,7 @@ proto_register_homeplug_av(void)
FT_ETHER, BASE_NONE, NULL, 0x00, NULL, HFILL }
},
{ &hf_homeplug_av_nw_info_sta_tei,
- { "Station Terminal Equipement Identifier", "homeplug_av.nw_info_cnf.sta_indo.tei",
+ { "Station Terminal Equipment Identifier", "homeplug_av.nw_info_cnf.sta_indo.tei",
FT_UINT8, BASE_DEC, NULL, 0x00, NULL, HFILL }
},
{ &hf_homeplug_av_nw_info_sta_bda,
diff --git a/epan/dissectors/packet-homeplug.c b/epan/dissectors/packet-homeplug.c
index 4389b29dee..5935d5cd17 100644
--- a/epan/dissectors/packet-homeplug.c
+++ b/epan/dissectors/packet-homeplug.c
@@ -1847,7 +1847,7 @@ proto_register_homeplug(void)
{ &hf_homeplug_hrsp_gfvr,
{ "Get Firmware Version", "homeplug.hrsp.gfvr",
- FT_UINT8, BASE_DEC, NULL, 0x0, "Get Firmwave Version", HFILL }
+ FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }
},
{ &hf_homeplug_hrsp_gnekr,
diff --git a/epan/dissectors/packet-pdcp-lte.c b/epan/dissectors/packet-pdcp-lte.c
index 0b02eca9e4..ed7199031e 100644
--- a/epan/dissectors/packet-pdcp-lte.c
+++ b/epan/dissectors/packet-pdcp-lte.c
@@ -2815,7 +2815,7 @@ void proto_register_pdcp(void)
{ &hf_pdcp_lte_security,
{ "Security Config",
- "pdcp-lte.security-cofig", FT_STRING, BASE_NONE, 0, 0x0,
+ "pdcp-lte.security-config", FT_STRING, BASE_NONE, 0, 0x0,
NULL, HFILL
}
},
diff --git a/epan/dissectors/packet-quic.c b/epan/dissectors/packet-quic.c
index 1179ebcf13..5110bd211c 100644
--- a/epan/dissectors/packet-quic.c
+++ b/epan/dissectors/packet-quic.c
@@ -2550,7 +2550,7 @@ dissect_quic_retry_packet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *quic_tr
}
retry_token_len = tvb_reported_length_remaining(tvb, offset);
- // Remove length of Retry Integrity Tag"
+ // Remove length of Retry Integrity Tag
if (!is_quic_draft_max(version, 24) && retry_token_len >= 16) {
retry_token_len -= 16;
}
diff --git a/epan/dissectors/packet-z3950.c b/epan/dissectors/packet-z3950.c
index c6c2ed78ed..90e0f0eb7c 100644
--- a/epan/dissectors/packet-z3950.c
+++ b/epan/dissectors/packet-z3950.c
@@ -227,7 +227,7 @@ static const value_string z3950_bib1_at_use[] = {
{ 1034, "Content-type" },
{ 1035, "Anywhere" },
{ 1036, "Author-Title-Subject" },
- { 1037, "Serial Item and Contribution Identifer (SICI)" },
+ { 1037, "Serial Item and Contribution Identifier (SICI)" },
{ 1038, "Abstract-language" },
{ 1039, "Application-kind" },
{ 1040, "Classification" },
@@ -1874,7 +1874,7 @@ static const value_string marc_tag_names[] = {
{ 1, "Control Number" },
{ 3, "Control Number Identifier" },
{ 5, "Date and Time of Latest Transaction" },
- { 6, "Fixed-length Data Elements - Addiional Matieral Characteristics" },
+ { 6, "Fixed-length Data Elements - Additional Material Characteristics" },
{ 8, "Fixed-length Data Elements" },
{ 7, "Physical Description Fixed Field" },
{ 10, "Library of Congress Control Number" },
@@ -2030,7 +2030,7 @@ static const value_string marc_tag_names[] = {
{ 955, "Local LoC Functional Identifying Information" },
{ 984, "Local LoC Shelflist Compare Status" },
{ 985, "Local LoC Record History" },
- { 987, "Local LoC Converstion History" },
+ { 987, "Local LoC Conversation History" },
{ 991, "Local LoC Location Information" },
{ 992, "Local LoC Location Information" },
{ 0, NULL}
diff --git a/epan/dissectors/packet-zbee-zcl-general.c b/epan/dissectors/packet-zbee-zcl-general.c
index 42e02b2dd2..7e9c718f0e 100644
--- a/epan/dissectors/packet-zbee-zcl-general.c
+++ b/epan/dissectors/packet-zbee-zcl-general.c
@@ -11995,7 +11995,7 @@ proto_register_zbee_zcl_pwr_prof(void)
"Identifier of the specific energy phase.", HFILL } },
{ &hf_zbee_zcl_pwr_prof_expect_duration,
- { "Expected Duration", "zbee_zcl_general.pwrprof.expecduration", FT_UINT16, BASE_CUSTOM, CF_FUNC(decode_zcl_time_in_minutes), 0x0,
+ { "Expected Duration", "zbee_zcl_general.pwrprof.expectduration", FT_UINT16, BASE_CUSTOM, CF_FUNC(decode_zcl_time_in_minutes), 0x0,
"The estimated duration of the specific phase.", HFILL } },
{ &hf_zbee_zcl_pwr_prof_num_of_trans_phases,
@@ -15084,7 +15084,7 @@ proto_register_zbee_zcl_gp(void)
{ "Commissioning window", "zbee_zcl_general.gp.proxy_comm_mode.comm_window", FT_UINT16, BASE_DEC,
NULL, 0x0, "Commissioning window in seconds", HFILL }},
{ &hf_zbee_zcl_gp_channel,
- { "Channel", "zbee_zcl_general.gp.proxy_comm_mode.cnannel", FT_UINT8, BASE_DEC,
+ { "Channel", "zbee_zcl_general.gp.proxy_comm_mode.channel", FT_UINT8, BASE_DEC,
NULL, 0x0, "Identifier of the channel the devices SHOULD switch to on reception", HFILL }},
{ &hf_zbee_gp_cmd_pcm_opt_action,
{ "Action", "zbee_zcl_general.gp.proxy_comm_mode.opt.action", FT_UINT8, BASE_DEC,
@@ -15460,7 +15460,7 @@ proto_register_zbee_zcl_gp(void)
{ "ApplicationID", "zbee_zcl_general.gp.sink_tbl.entry.opt.app_id", FT_UINT16, BASE_HEX,
NULL, ZBEE_ZCL_GP_SINK_TBL_OPT_APP_ID, NULL, HFILL }},
{ &hf_zbee_gp_sink_tbl_entry_options_comm_mode,
- { "Communicaton Mode", "zbee_zcl_general.gp.sink_tbl.entry.opt.comm_mode", FT_UINT16, BASE_HEX,
+ { "Communication Mode", "zbee_zcl_general.gp.sink_tbl.entry.opt.comm_mode", FT_UINT16, BASE_HEX,
VALS(zbee_zcl_gp_communication_modes), ZBEE_ZCL_GP_SINK_TBL_OPT_COMMUNICATION_MODE, NULL, HFILL }},
{ &hf_zbee_gp_sink_tbl_entry_options_seq_num_cap,
{ "Sequence number capabilities", "zbee_zcl_general.gp.sink_tbl.entry.opt.seq_num_cap", FT_BOOLEAN, 16,
diff --git a/epan/dissectors/packet-zbee-zcl-hvac.c b/epan/dissectors/packet-zbee-zcl-hvac.c
index ae29d2e1b4..d5f51ab30a 100644
--- a/epan/dissectors/packet-zbee-zcl-hvac.c
+++ b/epan/dissectors/packet-zbee-zcl-hvac.c
@@ -84,7 +84,7 @@
#define ZBEE_ZCL_PUMP_CONFIG_CONTROL_ALARM_SENSOR_FAILURE 0x0400 /* Sensor failure */
#define ZBEE_ZCL_PUMP_CONFIG_CONTROL_ALARM_ELEC_NON_FATAL_FAILURE 0x0800 /* Electronic non-fatal failure */
#define ZBEE_ZCL_PUMP_CONFIG_CONTROL_ALARM_ELEC_FATAL_FAILURE 0x1000 /* Electronic fatal failure */
-#define ZBEE_ZCL_PUMP_CONFIG_CONTROL_ALARM_GENERAL_FAULT 0x2000 /* Genral fault */
+#define ZBEE_ZCL_PUMP_CONFIG_CONTROL_ALARM_GENERAL_FAULT 0x2000 /* General fault */
/*************************/
/* Function Declarations */
@@ -171,7 +171,7 @@ static const value_string zbee_zcl_pump_config_control_attr_names[] = {
/*Operation Mode Values*/
static const value_string zbee_zcl_pump_config_control_operation_mode_names[] = {
- {0, "Noramal"},
+ {0, "Normal"},
{1, "Minimum"},
{2, "Maximum"},
{3, "Local"},
@@ -185,7 +185,7 @@ static const value_string zbee_zcl_pump_config_control_control_mode_names[] = {
{2, "proportional Pressure"},
{3, "Constant Flow"},
{4, "Reserved"},
- {5, "Constat Temperature"},
+ {5, "Constant Temperature"},
{6, "Reserved"},
{7, "Automatic"},
{0, NULL}
@@ -443,7 +443,7 @@ proto_register_zbee_zcl_pump_config_control(void)
ZBEE_ZCL_PUMP_CONFIG_CONTROL_ALARM_ELEC_FATAL_FAILURE, NULL, HFILL } },
{ &hf_zbee_zcl_pump_config_control_alarm_gen_fault,
- { "Genral fault", "zbee_zcl_hvac.pump_config_control.attr.alarm.gen_fault", FT_BOOLEAN, 8, TFS(&tfs_disabled_enabled),
+ { "General fault", "zbee_zcl_hvac.pump_config_control.attr.alarm.gen_fault", FT_BOOLEAN, 8, TFS(&tfs_disabled_enabled),
ZBEE_ZCL_PUMP_CONFIG_CONTROL_ALARM_GENERAL_FAULT, NULL, HFILL } }
/* end Alarm Mask fields */
};
diff --git a/epan/dissectors/packet-zbee-zcl-lighting.c b/epan/dissectors/packet-zbee-zcl-lighting.c
index bdf72e30b4..3092a59b15 100644
--- a/epan/dissectors/packet-zbee-zcl-lighting.c
+++ b/epan/dissectors/packet-zbee-zcl-lighting.c
@@ -1211,7 +1211,7 @@ proto_register_zbee_zcl_color_control(void)
0x00, NULL, HFILL } },
{ &hf_zbee_zcl_color_control_attr_current_saturation,
- { "Saturation", "zbee_zcl_lighting.color_control.attr.current_satuaration", FT_UINT8, BASE_DEC, NULL,
+ { "Saturation", "zbee_zcl_lighting.color_control.attr.current_saturation", FT_UINT8, BASE_DEC, NULL,
0x00, NULL, HFILL } },
{ &hf_zbee_zcl_color_control_attr_remaining_time,
@@ -1419,7 +1419,7 @@ proto_register_zbee_zcl_color_control(void)
0x00, NULL, HFILL } },
{ &hf_zbee_zcl_color_control_attr_startup_color_temperature,
- { "Startup Color Temparature", "zbee_zcl_lighting.color_control.attr.startup_color_temperature", FT_UINT16, BASE_CUSTOM, CF_FUNC(decode_startup_color_temperature),
+ { "Startup Color Temperature", "zbee_zcl_lighting.color_control.attr.startup_color_temperature", FT_UINT16, BASE_CUSTOM, CF_FUNC(decode_startup_color_temperature),
0x00, NULL, HFILL } },
{ &hf_zbee_zcl_color_control_hue,
@@ -1685,7 +1685,7 @@ static const value_string zbee_zcl_ballast_configuration_status_non_operational_
/*Not in Socket Values*/
static const value_string zbee_zcl_ballast_configuration_status_lamp_not_in_socket_names[] = {
{0, "All lamps in Socket"},
- {1, "Atleast one lamp not in Socket"},
+ {1, "At least one lamp not in Socket"},
{0, NULL}
};
diff --git a/epan/dissectors/packet-zbee-zdp.c b/epan/dissectors/packet-zbee-zdp.c
index 7be69b1379..e27827133a 100644
--- a/epan/dissectors/packet-zbee-zdp.c
+++ b/epan/dissectors/packet-zbee-zdp.c
@@ -1497,7 +1497,7 @@ void proto_register_zbee_zdp(void)
NULL, HFILL }},
{ &hf_zbee_zdp_server_stk_compl_rev,
- { "Stack Compliance Revision", "zbee_zdp.server.stack_compiance_revision", FT_UINT16, BASE_DEC, NULL, ZBEE_ZDP_NODE_SERVER_STACK_COMPL_REV,
+ { "Stack Compliance Revision", "zbee_zdp.server.stack_compliance_revision", FT_UINT16, BASE_DEC, NULL, ZBEE_ZDP_NODE_SERVER_STACK_COMPL_REV,
NULL, HFILL }},
{ &hf_zbee_zdp_node_type,
@@ -1561,7 +1561,7 @@ void proto_register_zbee_zdp(void)
NULL, HFILL }},
{ &hf_zbee_zdp_power_avail_dispose,
- { "Available Disposeable Battery", "zbee_zdp.power.avail.disp", FT_BOOLEAN, 16, NULL, ZBEE_ZDP_POWER_AVAIL_DISPOSEABLE,
+ { "Available Disposable Battery", "zbee_zdp.power.avail.disp", FT_BOOLEAN, 16, NULL, ZBEE_ZDP_POWER_AVAIL_DISPOSABLE,
NULL, HFILL }},
{ &hf_zbee_zdp_power_source_ac,
@@ -1573,7 +1573,7 @@ void proto_register_zbee_zdp(void)
NULL, HFILL }},
{ &hf_zbee_zdp_power_source_dispose,
- { "Using Disposeable Battery", "zbee_zdp.power.source.ac", FT_BOOLEAN, 16, NULL, ZBEE_ZDP_POWER_SOURCE_DISPOSEABLE,
+ { "Using Disposable Battery", "zbee_zdp.power.source.ac", FT_BOOLEAN, 16, NULL, ZBEE_ZDP_POWER_SOURCE_DISPOSABLE,
NULL, HFILL }},
{ &hf_zbee_zdp_power_level,
diff --git a/epan/dissectors/packet-zbee-zdp.h b/epan/dissectors/packet-zbee-zdp.h
index e7621ce5bf..59b11a0c2b 100644
--- a/epan/dissectors/packet-zbee-zdp.h
+++ b/epan/dissectors/packet-zbee-zdp.h
@@ -163,11 +163,11 @@
#define ZBEE_ZDP_POWER_AVAIL 0x00f0
#define ZBEE_ZDP_POWER_AVAIL_AC 0x0010
#define ZBEE_ZDP_POWER_AVAIL_RECHARGEABLE 0x0020
-#define ZBEE_ZDP_POWER_AVAIL_DISPOSEABLE 0x0040
+#define ZBEE_ZDP_POWER_AVAIL_DISPOSABLE 0x0040
#define ZBEE_ZDP_POWER_SOURCE 0x0f00
#define ZBEE_ZDP_POWER_SOURCE_AC 0x0100
#define ZBEE_ZDP_POWER_SOURCE_RECHARGEABLE 0x0200
-#define ZBEE_ZDP_POWER_SOURCE_DISPOSEABLE 0x0400
+#define ZBEE_ZDP_POWER_SOURCE_DISPOSABLE 0x0400
#define ZBEE_ZDP_POWER_LEVEL 0xf000
#define ZBEE_ZDP_POWER_LEVEL_FULL 0xc000
#define ZBEE_ZDP_POWER_LEVEL_OK 0x8000
diff --git a/epan/dissectors/packet-zebra.c b/epan/dissectors/packet-zebra.c
index df5a2b9522..4d20906769 100644
--- a/epan/dissectors/packet-zebra.c
+++ b/epan/dissectors/packet-zebra.c
@@ -202,7 +202,7 @@ static const value_string messages[] = {
{ ZEBRA_HELLO, "Hello" },
{ ZEBRA_IPV4_NEXTHOP_LOOKUP_MRIB, "IPv4 Nexthop Lookup Multicast RIB" },
{ ZEBRA_VRF_UNREGISTER, "VRF Unregister" },
- { ZEBRA_INTERFACE_LINK_PARAMS, "Interface Link Paameters" },
+ { ZEBRA_INTERFACE_LINK_PARAMS, "Interface Link Parameters" },
{ ZEBRA_NEXTHOP_REGISTER, "Nexthop Register" },
{ ZEBRA_NEXTHOP_UNREGISTER, "Nexthop Unregister" },
{ ZEBRA_NEXTHOP_UPDATE, "Nexthop Update" },
@@ -315,10 +315,10 @@ static const value_string frr_zapi4_messages[] = {
{ FRR_ZAPI4_VRF_DELETE, "VRF Delete" },
{ FRR_ZAPI4_INTERFACE_VRF_UPDATE, "Interface VRF Update" },
{ FRR_ZAPI4_BFD_CLIENT_REGISTER, "BFD Client Register" },
- { FRR_ZAPI4_INTERFACE_ENABLE_RADV, "Interface Enable Rouer Advertisement" },
- { FRR_ZAPI4_INTERFACE_DISABLE_RADV, "Interface Disable Rouer Advertisement" },
+ { FRR_ZAPI4_INTERFACE_ENABLE_RADV, "Interface Enable Router Advertisement" },
+ { FRR_ZAPI4_INTERFACE_DISABLE_RADV, "Interface Disable Router Advertisement" },
{ FRR_ZAPI4_IPV4_NEXTHOP_LOOKUP_MRIB, "IPv4 Nexthop Lookup Multicast RIB" },
- { FRR_ZAPI4_INTERFACE_LINK_PARAMS, "Interface Link Paameters" },
+ { FRR_ZAPI4_INTERFACE_LINK_PARAMS, "Interface Link Parameters" },
{ FRR_ZAPI4_MPLS_LABELS_ADD, "MPLS Labels Add" },
{ FRR_ZAPI4_MPLS_LABELS_DELETE, "MPLS Labels Delete" },
{ FRR_ZAPI4_IPV4_NEXTHOP_ADD, "Add IPv4 Nexthop" },
@@ -478,10 +478,10 @@ static const value_string frr_zapi5_messages[] = {
{ FRR_ZAPI5_VRF_LABEL, "VRF Label" },
{ FRR_ZAPI5_INTERFACE_VRF_UPDATE, "Interface VRF Update" },
{ FRR_ZAPI5_BFD_CLIENT_REGISTER, "BFD Client Register" },
- { FRR_ZAPI5_INTERFACE_ENABLE_RADV, "Interface Enable Rouer Advertisement" },
- { FRR_ZAPI5_INTERFACE_DISABLE_RADV, "Interface Disable Rouer Advertisement" },
+ { FRR_ZAPI5_INTERFACE_ENABLE_RADV, "Interface Enable Router Advertisement" },
+ { FRR_ZAPI5_INTERFACE_DISABLE_RADV, "Interface Disable Router Advertisement" },
{ FRR_ZAPI5_IPV4_NEXTHOP_LOOKUP_MRIB, "IPv4 Nexthop Lookup Multicast RIB" },
- { FRR_ZAPI5_INTERFACE_LINK_PARAMS, "Interface Link Paameters" },
+ { FRR_ZAPI5_INTERFACE_LINK_PARAMS, "Interface Link Parameters" },
{ FRR_ZAPI5_MPLS_LABELS_ADD, "MPLS Labels Add" },
{ FRR_ZAPI5_MPLS_LABELS_DELETE, "MPLS Labels Delete" },
{ FRR_ZAPI5_IPMR_ROUTE_STATS, "IPMR Route Statics" },
@@ -492,7 +492,7 @@ static const value_string frr_zapi5_messages[] = {
{ FRR_ZAPI5_FEC_REGISTER, "FEC Register" },
{ FRR_ZAPI5_FEC_UNREGISTER, "FEC Unregister" },
{ FRR_ZAPI5_FEC_UPDATE, "FEC Update" },
- { FRR_ZAPI5_ADVERTISE_DEFAULT_GW, "Advertise Deffault Gateway" },
+ { FRR_ZAPI5_ADVERTISE_DEFAULT_GW, "Advertise Default Gateway" },
{ FRR_ZAPI5_ADVERTISE_SUBNET, "Advertise Subnet" },
{ FRR_ZAPI5_ADVERTISE_ALL_VNI, "Advertise all VNI" },
{ FRR_ZAPI5_VNI_ADD, "VNI Add" },
@@ -502,7 +502,7 @@ static const value_string frr_zapi5_messages[] = {
{ FRR_ZAPI5_REMOTE_VTEP_ADD, "Remote VTEP Add" },
{ FRR_ZAPI5_REMOTE_VTEP_DEL, "Remote VTEP Delete" },
{ FRR_ZAPI5_MACIP_ADD, "MAC/IP Add" },
- { FRR_ZAPI5_MACIP_DEL, "MAC/IP Dleate" },
+ { FRR_ZAPI5_MACIP_DEL, "MAC/IP Delete" },
{ FRR_ZAPI5_IP_PREFIX_ROUTE_ADD, "IP Prefix Route Add" },
{ FRR_ZAPI5_IP_PREFIX_ROUTE_DEL, "IP Prefix Route Delete" },
{ FRR_ZAPI5_REMOTE_MACIP_ADD, "Remote MAC/IP Add" },
@@ -669,10 +669,10 @@ static const value_string frr_zapi6_messages[] = {
{ FRR_ZAPI6_INTERFACE_VRF_UPDATE, "Interface VRF Update" },
{ FRR_ZAPI6_BFD_CLIENT_REGISTER, "BFD Client Register" },
{ FRR_ZAPI6_BFD_CLIENT_DEREGISTER, "BFD Client Deregister" },
- { FRR_ZAPI6_INTERFACE_ENABLE_RADV, "Interface Enable Rouer Advertisement" },
- { FRR_ZAPI6_INTERFACE_DISABLE_RADV, "Interface Disable Rouer Advertisement" },
+ { FRR_ZAPI6_INTERFACE_ENABLE_RADV, "Interface Enable Router Advertisement" },
+ { FRR_ZAPI6_INTERFACE_DISABLE_RADV, "Interface Disable Router Advertisement" },
{ FRR_ZAPI6_IPV4_NEXTHOP_LOOKUP_MRIB, "IPv4 Nexthop Lookup Multicast RIB" },
- { FRR_ZAPI6_INTERFACE_LINK_PARAMS, "Interface Link Paameters" },
+ { FRR_ZAPI6_INTERFACE_LINK_PARAMS, "Interface Link Parameters" },
{ FRR_ZAPI6_MPLS_LABELS_ADD, "MPLS Labels Add" },
{ FRR_ZAPI6_MPLS_LABELS_DELETE, "MPLS Labels Delete" },
{ FRR_ZAPI6_IPMR_ROUTE_STATS, "IPMR Route Statics" },
@@ -683,7 +683,7 @@ static const value_string frr_zapi6_messages[] = {
{ FRR_ZAPI6_FEC_REGISTER, "FEC Register" },
{ FRR_ZAPI6_FEC_UNREGISTER, "FEC Unregister" },
{ FRR_ZAPI6_FEC_UPDATE, "FEC Update" },
- { FRR_ZAPI6_ADVERTISE_DEFAULT_GW, "Advertise Deffault Gateway" },
+ { FRR_ZAPI6_ADVERTISE_DEFAULT_GW, "Advertise Default Gateway" },
{ FRR_ZAPI6_ADVERTISE_SUBNET, "Advertise Subnet" },
{ FRR_ZAPI6_ADVERTISE_ALL_VNI, "Advertise all VNI" },
{ FRR_ZAPI6_LOCAL_ES_ADD, "Local Ethernet Segment Add" },
@@ -695,7 +695,7 @@ static const value_string frr_zapi6_messages[] = {
{ FRR_ZAPI6_REMOTE_VTEP_ADD, "Remote VTEP Add" },
{ FRR_ZAPI6_REMOTE_VTEP_DEL, "Remote VTEP Delete" },
{ FRR_ZAPI6_MACIP_ADD, "MAC/IP Add" },
- { FRR_ZAPI6_MACIP_DEL, "MAC/IP Dleate" },
+ { FRR_ZAPI6_MACIP_DEL, "MAC/IP Delete" },
{ FRR_ZAPI6_IP_PREFIX_ROUTE_ADD, "IP Prefix Route Add" },
{ FRR_ZAPI6_IP_PREFIX_ROUTE_DEL, "IP Prefix Route Delete" },
{ FRR_ZAPI6_REMOTE_MACIP_ADD, "Remote MAC/IP Add" },
@@ -982,7 +982,7 @@ static const value_string blackhole_type[] = {
{ BLACKHOLE_UNSPEC, "Unspec" },
{ BLACKHOLE_NULL, "NULL" },
{ BLACKHOLE_REJECT, "Reject" },
- { BLACKHOLE_ADMINPROHIB, "Adminisrative Prohibit" },
+ { BLACKHOLE_ADMINPROHIB, "Administrative Prohibit" },
{ 0, NULL},
};
@@ -2379,11 +2379,11 @@ proto_register_zebra(void)
{ &hf_zebra_version,
{ "Version", "zebra.version",
FT_UINT8, BASE_DEC, NULL, 0x0,
- "Zerbra srv version", HFILL }},
+ "Zebra srv version", HFILL }},
{ &hf_zebra_marker,
{ "Marker", "zebra.marker",
FT_UINT8, BASE_HEX, NULL, 0x0,
- "Zerbra srv marker", HFILL }},
+ "Zebra srv marker", HFILL }},
{ &hf_zebra_request,
{ "Request", "zebra.request",
FT_BOOLEAN, BASE_NONE, NULL, 0x0,
@@ -2669,7 +2669,7 @@ proto_register_zebra(void)
{ &hf_zebra_bhtype,
{ "BHType", "zebra.bhtype",
FT_UINT8, BASE_DEC, VALS(blackhole_type), 0x0,
- "Bkackhole Type", HFILL }},
+ "Blackhole Type", HFILL }},
{ &hf_zebra_srcprefixlen,
{ "Source Prefix length", "zebra.srcprefixlen",
FT_UINT32, BASE_DEC,
@@ -2714,23 +2714,23 @@ proto_register_zebra(void)
{ &hf_zebra_label_chunk_keep,
{ "Label Chunk Keep", "zebra.label_chunk_keep",
FT_UINT8, BASE_DEC, NULL, 0x0,
- "Keep of Lable Chunk", HFILL }},
+ "Keep of Label Chunk", HFILL }},
{ &hf_zebra_label_chunk_size,
{ "Label Chunk Size", "zebra.label_chunk_size",
FT_UINT32, BASE_DEC, NULL, 0x0,
- "Size of Lable Chunk", HFILL }},
+ "Size of Label Chunk", HFILL }},
{ &hf_zebra_label_chunk_start,
{ "Label Chunk Start","zebra.label_chunk_start",
FT_UINT32, BASE_DEC, NULL, 0x0,
- "Start of Lable Chunk", HFILL }},
+ "Start of Label Chunk", HFILL }},
{ &hf_zebra_label_chunk_end,
{ "Label Chunk End", "zebra.label_chunk_end",
FT_UINT32, BASE_DEC, NULL, 0x0,
- "End of Lable Chunk", HFILL }},
+ "End of Label Chunk", HFILL }},
{ &hf_zebra_mpls_enabled,
{ "MPLS Enabled", "zebra.mpls_enabled",
FT_BOOLEAN, BASE_NONE, NULL, 0x0,
- "MPLS enabled capablity", HFILL }},
+ "MPLS enabled capability", HFILL }},
{ &hf_zebra_multipath_num,
{ "Multipath Number", "zebra.multipath_num",
FT_UINT32, BASE_DEC, NULL, 0x0,
diff --git a/epan/dissectors/packet-zvt.c b/epan/dissectors/packet-zvt.c
index b29418e973..e7f714a67c 100644
--- a/epan/dissectors/packet-zvt.c
+++ b/epan/dissectors/packet-zvt.c
@@ -275,7 +275,7 @@ static const value_string bitmap[] = {
{ BMP_TRACE_NUM, "Trace number" },
{ BMP_TIME, "Time" },
{ BMP_DATE, "Date" },
- { BMP_EXP_DATE, "Exipry date" },
+ { BMP_EXP_DATE, "Expiry date" },
{ BMP_CARD_SEQ_NUM, "Card sequence number" },
{ BMP_PAYMENT_TYPE, "Payment type" },
{ BMP_CARD_NUM, "Card number" },
diff --git a/epan/dissectors/packet-acn.c b/epan/dissectors/packet-acn.c
index 3fbb5e8e35..556099e13b 100644
--- a/epan/dissectors/packet-acn.c
+++ b/epan/dissectors/packet-acn.c
@@ -733,7 +733,7 @@ static int hf_rdmnet_ept_vector = -1;
static int hf_rdmnet_ept_destination_cid = -1;
static int hf_rdmnet_ept_data_pdu_length = -1;
static int hf_rdmnet_ept_data_vector = -1;
-static int hf_rdmnet_ept_data_vector_manfacturer_id = -1;
+static int hf_rdmnet_ept_data_vector_manufacturer_id = -1;
static int hf_rdmnet_ept_data_vector_protocol_id = -1;
static int hf_rdmnet_ept_data_opaque_data = -1;
static int hf_rdmnet_ept_status_pdu_length = -1;
@@ -751,7 +751,7 @@ static const value_string acn_protocol_id_vals[] = {
{ ACN_PROTOCOL_ID_RPT, "RDM Packet Transport Protocol" },
{ ACN_PROTOCOL_ID_BROKER, "Broker Protocol" },
{ ACN_PROTOCOL_ID_LLRP, "Low Level Recovery Protocol" },
- { ACN_PROTOCOL_ID_EPT, "Etensible Packet Transport Protocol" },
+ { ACN_PROTOCOL_ID_EPT, "Extensible Packet Transport Protocol" },
{ 0, NULL },
};
@@ -1029,7 +1029,7 @@ static const value_string acn_blob_dimmer_rack_status_properties2_field_name[] =
{ 9, "Space" },
{ 10, "UDN" },
{ 11, "Reserved" },
- { 12, "CPU Tempeture" },
+ { 12, "CPU Temperature" },
{ 13, "Time of Last Reboot" },
{ 14, "Time Now" },
{ 15, "Rack Phasing" },
@@ -1504,7 +1504,7 @@ static const value_string acn_blob_dimmer_rack_status_properties1_field_name[] =
{ 9, "Space" },
{ 10, "UDN" },
{ 11, "Reserved" },
- { 12, "CPU Tempeture" },
+ { 12, "CPU Temperature" },
{ 13, "Time of Last Reboot" },
{ 14, "Time Now" },
{ 15, "Rack Phasing" },
@@ -6822,7 +6822,7 @@ dissect_ept_data(tvbuff_t *tvb, proto_tree *tree, int offset, acn_pdu_offsets *l
/* esta manufacturer id + protocol id (4 bytes) */
ti2 = proto_tree_add_item(pdu_tree, hf_rdmnet_ept_data_vector, tvb, data_offset, 4, ENC_BIG_ENDIAN);
pdu_tree2 = proto_item_add_subtree(ti2, ett_rdmnet_ept_data_vector_pdu);
- proto_tree_add_item(pdu_tree2, hf_rdmnet_ept_data_vector_manfacturer_id, tvb, 0, 2, ENC_BIG_ENDIAN);
+ proto_tree_add_item(pdu_tree2, hf_rdmnet_ept_data_vector_manufacturer_id, tvb, 0, 2, ENC_BIG_ENDIAN);
proto_tree_add_item(pdu_tree2, hf_rdmnet_ept_data_vector_protocol_id, tvb, 2, 2, ENC_BIG_ENDIAN);
data_offset += 4;
@@ -8458,11 +8458,11 @@ proto_register_acn(void)
FT_UINT32, BASE_HEX, NULL, 0x0,
"Data vector", HFILL }
},
- /* EPT Data Vector Manfacturer ID */
- { &hf_rdmnet_ept_data_vector_manfacturer_id,
- { "Manfac. ID", "rdmnet.ept.data.vector.manfacturer_id",
+ /* EPT Data Vector Manufacturer ID */
+ { &hf_rdmnet_ept_data_vector_manufacturer_id,
+ { "Manufac. ID", "rdmnet.ept.data.vector.manufacturer_id",
FT_UINT16, BASE_HEX, NULL, 0x0,
- "Manfacturer id", HFILL }
+ "Manufacturer id", HFILL }
},
/* EPT Data Vector Protocol ID */
{ &hf_rdmnet_ept_data_vector_protocol_id,
diff --git a/epan/dissectors/packet-grpc.c b/epan/dissectors/packet-grpc.c
index 3835f54741..993befca5f 100644
--- a/epan/dissectors/packet-grpc.c
+++ b/epan/dissectors/packet-grpc.c
@@ -80,7 +80,7 @@ static gboolean grpc_decompress_body = TRUE;
static gboolean grpc_decompress_body = FALSE;
#endif
/* detect json automaticlly */
static gboolean grpc_detect_json_automatically = TRUE;
/* tell http2 to use streaming mode reassembly for grpc dissector */
static gboolean grpc_enable_streaming_reassembly_mode = TRUE;
@@ -395,7 +395,7 @@ proto_register_grpc(void)
grpc_module = prefs_register_protocol(proto_grpc, proto_reg_handoff_grpc);
- prefs_register_bool_preference(grpc_module, "detect_json_automaticlly",
+ prefs_register_bool_preference(grpc_module, "detect_json_automatically",
"Always check whether the message is JSON regardless of content-type.",
"Normally application/grpc message is protobuf, "
"but sometime the true message is json. "
@@ -414,7 +414,7 @@ proto_register_grpc(void)
"to keep this option on.",
&grpc_enable_streaming_reassembly_mode);
- prefs_register_bool_preference(grpc_module, "embeded_under_http2",
+ prefs_register_bool_preference(grpc_module, "embedded_under_http2",
"Embed gRPC messages under HTTP2 protocol tree items.",
"Embed gRPC messages under HTTP2 protocol tree items.",
&grpc_embedded_under_http2);
@@ -80,7 +80,7 @@ static gboolean grpc_decompress_body = TRUE;
static gboolean grpc_decompress_body = FALSE;
#endif
-/* detect json automaticlly */
+/* detect json automatically */
static gboolean grpc_detect_json_automatically = TRUE;
/* tell http2 to use streaming mode reassembly for grpc dissector */